@@ -1,8 +1,8 @@
 /***************************************************************************
-date                 : Febr 18 2005
-version              : 0.12
-copyright            : (C) 2004-2005 by Holger Danielsson
-email                : holger.danielsson@t-online.de
+    date                 : Mar 21 2007
+    version              : 0.40
+    copyright            : (C) 2004-2007 by Holger Danielsson
+    email                : holger.danielsson@versanet.de
 ***************************************************************************/
 
 /***************************************************************************
@@ -13,13 +13,15 @@ email                : holger.danielsson@t-online.de
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- 
+
+#include "codecompletion.h"
+
 #include <qregexp.h>
 #include <qfile.h>
 #include <qtimer.h>
 #include <qdict.h>
 
-#include <kdebug.h>
+#include "kiledebug.h"
 #include <klocale.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
@@ -29,26 +31,38 @@ email                : holger.danielsson@t-online.de
 
 #include "kileinfo.h"
 #include "kileviewmanager.h"
-#include "codecompletion.h"
 #include "kileconfig.h"
+#include "kileedit.h"
 
 namespace KileDocument
 {
 
-	static QRegExp::QRegExp reRef("^\\\\(pageref|ref)\\{");
-	static QRegExp::QRegExp reCite("^\\\\(c|C|noc)(ite|itep|itet|itealt|itealp|iteauthor|iteyear|iteyearpar|itetext)\\{");
-	static QRegExp::QRegExp reRefExt("^\\\\(pageref|ref)\\{[^\\{\\}\\\\]+,$");
-	static QRegExp::QRegExp reCiteExt("^\\\\(c|C|noc)(ite|itep|itet|itealt|itealp|iteauthor|iteyear|iteyearpar|itetext)\\{[^\\{\\}\\\\]+,$");
-	
-	static QRegExp::QRegExp reNotRefChars("[^a-zA-z0-9_@\\+\\-\\*\\:]");
-	
+	//static QRegExp::QRegExp reRef("^\\\\(pageref|ref)\\{");
+	//static QRegExp::QRegExp reCite("^\\\\(c|C|noc)(ite|itep|itet|itealt|itealp|iteauthor|iteyear|iteyearpar|itetext)\\{");
+	//static QRegExp::QRegExp reRefExt("^\\\\(pageref|ref)\\{[^\\{\\}\\\\]+,$");
+	//static QRegExp::QRegExp reCiteExt("^\\\\(c|C|noc)(ite|itep|itet|itealt|itealp|iteauthor|iteyear|iteyearpar|itetext)\\{[^\\{\\}\\\\]+,$");
+
+	static QRegExp::QRegExp reRef;
+	static QRegExp::QRegExp reRefExt;
+	static QRegExp::QRegExp reCite;
+	static QRegExp::QRegExp reCiteExt;
+	static QRegExp::QRegExp reNotRefChars("[^a-zA-Z0-9_@\\.\\+\\-\\*\\:]");
+	static QRegExp::QRegExp reNotCiteChars("[^a-zA-Z0-9_@]");
+
 	CodeCompletion::CodeCompletion(KileInfo *info) : m_ki(info), m_view(0L)
 	{
 		m_firstconfig = true;
 		m_inprogress = false;
 		m_undo = false;
 		m_ref = false;
+		m_kilecompletion = false;
+		m_keylistType = CodeCompletion::ctNone;
 
+		// local abbreviation list
+		m_abbrevListview = 0L;
+		m_localAbbrevFile = locateLocal("appdata", "complete/abbreviation/", true) + "kile-abbrevs.cwl";
+
+		//reRef.setPattern("^\\\\(pageref|ref|xyz)\\{");
 		m_completeTimer = new QTimer( this );
 		connect(m_completeTimer, SIGNAL( timeout() ), this, SLOT( slotCompleteValueList() ) );
 	}
@@ -90,29 +104,66 @@ namespace KileDocument
 		return m_mode;
 	}
 
+	CodeCompletion::Type CodeCompletion::insideReference(QString &startpattern)
+	{
+		if ( m_view->getDoc() )
+		{
+			uint column = m_view->cursorColumnReal();
+			QString currentline = m_view->getDoc()->textLine(m_view->cursorLine()).left(column);
+			int pos = currentline.findRev('\\');
+			if ( pos >= 0 )
+			{
+
+				QString command = currentline.mid(pos,column-pos);
+ 				if ( command.find(reRef) != -1 )
+				{
+					startpattern = command.right(command.length()-reRef.cap(0).length());
+					if ( startpattern.find(reNotRefChars) == -1 )
+						return CodeCompletion::ctReference ;
+				}
+				else if ( command.find(reCite) != -1 )
+				{
+					startpattern = command.right(command.length()-reCite.cap(0).length());
+					if ( startpattern.find(reNotCiteChars) == -1 )
+						return CodeCompletion::ctCitation ;
+				}
+			}
+		}
+
+		return CodeCompletion::ctNone;
+	}
+
 	//////////////////// configuration ////////////////////
 
-	void CodeCompletion::readConfig(void)
+	void CodeCompletion::readConfig(KConfig *config)
 	{
-		kdDebug() << "=== CodeCompletion::readConfig ===================" << endl;
+		KILE_DEBUG() << "=== CodeCompletion::readConfig ===================" << endl;
 
 		// save normal parameter
-		kdDebug() << "   read bool entries" << endl;
+		//KILE_DEBUG() << "   read bool entries" << endl;
 		m_isenabled = KileConfig::completeEnabled();
 		m_setcursor = KileConfig::completeCursor();
 		m_setbullets = KileConfig::completeBullets();
 		m_closeenv = KileConfig::completeCloseEnv();
 		m_autocomplete = KileConfig::completeAuto();
 		m_autocompletetext = KileConfig::completeAutoText();
+		m_autocompleteabbrev = KileConfig::completeAutoAbbrev();
 		m_latexthreshold = KileConfig::completeAutoThreshold();
 		m_textthreshold = KileConfig::completeAutoTextThreshold();
+		m_citationMove = KileConfig::completeCitationMove();
+		m_autoDollar = KileConfig::autoInsertDollar();
+
+		// we need to read some of Kate's config flags
+		readKateConfigFlags(config);
 
 		// reading the wordlists is only necessary at the first start
 		// and when the list of files changes
-		if ( m_firstconfig || KileConfig::completeChangedLists() )
+		if ( m_firstconfig || KileConfig::completeChangedLists()  || KileConfig::completeChangedCommands() )
 		{
-			kdDebug() << "   read wordlists..." << endl;
+			KILE_DEBUG() << "   set regexp for references..." << endl;
+			setReferences();
 
+			KILE_DEBUG() << "   read wordlists..." << endl;
 			// wordlists for Tex/Latex mode
 			QStringList files = KileConfig::completeTex();
 			setWordlist( files, "tex", &m_texlist );
@@ -128,40 +179,173 @@ namespace KileDocument
 			// remember changed lists
 			m_firstconfig = false;
 			KileConfig::setCompleteChangedLists(false);
+			KileConfig::setCompleteChangedCommands(false);
 		}
-
 	}
 
+	void CodeCompletion::readKateConfigFlags(KConfig *config)
+	{
+		config->setGroup("Kate Document Defaults");
+		m_autobrackets = ( config->readNumEntry("Basic Config Flags",0) & cfAutoBrackets );
+		m_autoindent   = ( config->readNumEntry("Indentation Mode",0) > 0 );
+	}
+
+	// save local abbreviation changes
+	// (for example before a new configuration should be read)
+
+	void CodeCompletion::saveLocalChanges()
+	{
+		KILE_DEBUG() << "=== CodeCompletion::saveLocalChanges ===================" << endl;
+		m_abbrevListview->saveLocalAbbreviation(m_localAbbrevFile);
+	}
+
+	//////////////////// references and citations ////////////////////
+
+	void CodeCompletion::setReferences()
+	{
+		// build list of references
+		QString references = getCommandList(KileDocument::CmdAttrReference);
+		references.replace("*","\\*");
+		reRef.setPattern("^\\\\(" + references + ")\\{");
+		reRefExt.setPattern("^\\\\(" + references + ")\\{[^\\{\\}\\\\]+,$");
+
+		// build list of citations
+		QString citations = getCommandList(KileDocument::CmdAttrCitations);
+		citations.replace("*","\\*");
+		reCite.setPattern("^\\\\(((c|C|noc)(ite|itep|itet|itealt|itealp|iteauthor|iteyear|iteyearpar|itetext))" + citations +  ")\\{");
+		reCiteExt.setPattern("^\\\\(((c|C|noc)(ite|itep|itet|itealt|itealp|iteauthor|iteyear|iteyearpar|itetext))" + citations + ")\\{[^\\{\\}\\\\]+,$");
+	}
+
+	QString CodeCompletion::getCommandList(KileDocument::CmdAttribute attrtype)
+	{
+		QStringList cmdlist;
+		QStringList::ConstIterator it;
+
+		// get info about user defined references
+		KileDocument::LatexCommands *cmd = m_ki->latexCommands();
+		cmd->commandList(cmdlist,attrtype,false);
+
+		// build list of references
+		QString commands = QString::null;
+		for ( it=cmdlist.begin(); it != cmdlist.end(); ++it )
+		{
+			if ( cmd->isStarredEnv(*it) )
+				commands += '|' + (*it).mid(1) + '*';
+			commands += '|' + (*it).mid(1);
+		}
+		return commands;
+	}
+
+	//////////////////// wordlists ////////////////////
+
 	void CodeCompletion::setWordlist( const QStringList &files, const QString &dir,
 	                                  QValueList<KTextEditor::CompletionEntry> *entrylist
 	                                )
 	{
+
+		// read wordlists from files
 		QStringList wordlist;
 		for ( uint i = 0; i < files.count(); ++i )
 		{
 			// if checked, the wordlist has to be read
 			if ( files[ i ].at( 0 ) == '1' )
 			{
-				readWordlist( wordlist, dir + "/" + files[ i ].right( files[ i ].length() - 2 ) + ".cwl" );
+				readWordlist( wordlist, dir + '/' + files[i].right( files[i].length()-2 ) + ".cwl", true );
 			}
 		}
 
-		// sort the wordlist
-		// wordlist.sort();
+		// add user defined commands and environments
+		if ( dir == "tex" )
+		{
+			addCommandsToTexlist(wordlist);
+			setCompletionEntriesTexmode( entrylist, wordlist );
+		}
+		else if ( dir == "dictionary" )
+		{
+			wordlist.sort();
+			setCompletionEntries( entrylist, wordlist );
+		}
+		else if ( dir == "abbreviation" )
+		{
+			// read local wordlist
+			QStringList localWordlist;
+			readWordlist(localWordlist, QString::null, false);
 
-		// build all completion entries
-		setCompletionEntries( entrylist, wordlist );
+			// add local/global wordlists to the abbreviation view
+			m_abbrevListview->init(&wordlist,&localWordlist);
+
+			// finally add local wordlists to the abbreviation list
+			QStringList::ConstIterator it;
+			for ( it=localWordlist.begin(); it!=localWordlist.end(); ++it )
+				wordlist.append( *it );
+
+			wordlist.sort();
+			setCompletionEntries( entrylist, wordlist );
+		}
 	}
 
+	void CodeCompletion::addCommandsToTexlist(QStringList &wordlist)
+	{
+		QStringList cmdlist;
+		QStringList::ConstIterator it;
+		KileDocument::LatexCmdAttributes attr;
+
+		// get info about user defined commands and environments
+		KileDocument::LatexCommands *cmd = m_ki->latexCommands();
+		cmd->commandList(cmdlist,KileDocument::CmdAttrNone,true);
+
+		// add entries to wordlist
+		for ( it=cmdlist.begin(); it != cmdlist.end(); ++it )
+		{
+			if ( cmd->commandAttributes(*it,attr) )
+			{
+				QString command,eos;
+				QStringList entrylist;
+				if ( attr.type < KileDocument::CmdAttrLabel )          // environment
+				{
+					command = "\\begin{" + (*it);
+					eos = "}";
+				}
+				else                                                   // command
+				{
+					command = (*it);
+					// eos = QString::null;
+				}
+
+				// get all possibilities into a stringlist
+				entrylist.append( command + eos );
+				if ( ! attr.option.isEmpty() )
+					entrylist.append( command + eos + "[option]" );
+				if ( attr.starred )
+				{
+					entrylist.append( command + '*' + eos );
+					if ( ! attr.option.isEmpty() )
+						entrylist.append( command + '*' + eos + "[option]" );
+				}
+
+				// finally append entries to wordlist
+				QStringList::ConstIterator itentry;
+				for ( itentry=entrylist.begin(); itentry != entrylist.end(); ++itentry )
+				{
+					QString entry = (*itentry);
+					if ( ! attr.parameter.isEmpty()  )
+						entry += "{param}";
+					if ( attr.type == KileDocument::CmdAttrList )
+						entry += "\\item";
+					wordlist.append( entry );
+				}
+			}
+		}
+	}
 
 	//////////////////// completion box ////////////////////
 
 	void CodeCompletion::completeWord(const QString &text, CodeCompletion::Mode mode)
 	{
-		kdDebug() << "==CodeCompletion::completeWord(" << text << ")=========" << endl;
-		kdDebug() << "\tm_view = " << m_view << endl;
+		KILE_DEBUG() << "==CodeCompletion::completeWord(" << text << ")=========" << endl;
+		//KILE_DEBUG() << "\tm_view = " << m_view << endl;
 		if ( !m_view) return;
-		kdDebug() << "ok" << endl;
+		//KILE_DEBUG() << "ok" << endl;
 
 		// remember all parameters (view, pattern, length of pattern, mode)
 		m_text = text;
@@ -180,7 +364,7 @@ namespace KileDocument
 			QString s = doc->textLine(m_ycursor);
 			int pos = s.findRev("\\",m_xcursor);
 			if (pos < 0) {
-				kdDebug() << "\tfound no backslash! s=" << s << endl;
+				//KILE_DEBUG() << "\tfound no backslash! s=" << s << endl;
 				return;
 			}
 			m_xstart = pos;
@@ -193,14 +377,10 @@ namespace KileDocument
 		QValueList<KTextEditor::CompletionEntry> list;
 		switch ( m_mode )
 		{
-				case cmLatex:
-        kdDebug() << "mode = cmLatex" << endl;
-        list = m_texlist;
-        appendNewCommands(list);
-        break;
+				case cmLatex: // fall through here
 				case cmEnvironment:
-        kdDebug() << "mode = cmEnvironment" << endl;
-				list = m_texlist;				
+				list = m_texlist;
+				appendNewCommands(list);
 				break;
 				case cmDictionary:
 				list = m_dictlist;
@@ -220,8 +400,8 @@ namespace KileDocument
 		QString entry, type;
 		QString pattern = ( m_mode != cmEnvironment ) ? text : "\\begin{" + text;
 		uint n = countEntries( pattern, &list, &entry, &type );
-		
-		kdDebug() << "entries = " << n << endl;
+
+		//KILE_DEBUG() << "entries = " << n << endl;
 
 		// nothing to do
 		if ( n == 0 )
@@ -270,29 +450,32 @@ namespace KileDocument
 		}
 	}
 
-	void CodeCompletion::completeFromList(const QStringList *list )
+	void CodeCompletion::completeFromList(const QStringList *list,const QString &pattern)
 	{
 		KTextEditor::CompletionEntry e;
 
-		kdDebug() << "completeFromList: " << list->count() << " items" << endl;
+		KILE_DEBUG() << "completeFromList: " << list->count() << " items" <<   " << pattern=" << pattern<< endl;
+		QStringList sortedlist( *list );
+		sortedlist.sort();
+
 		m_labellist.clear();
 		QStringList::ConstIterator it;
-		QStringList::ConstIterator itend(list->end());
-		for ( it = list->begin(); it != itend; ++it )
+		QStringList::ConstIterator itend(sortedlist.end());
+		for ( it = sortedlist.begin(); it != itend; ++it )
 		{
 			e.text = *it;
 			m_labellist.append(  e );
 		}
 
-		completeWord("", cmLabel);
+		completeWord(pattern, cmLabel);
 	}
 
 	//////////////////// completion was done ////////////////////
 
 	void CodeCompletion::CompletionDone(KTextEditor::CompletionEntry)
 	{
-		// is there a new cursor position?
-		if ( m_setcursor && ( m_xoffset != 0 || m_yoffset != 0 ) && m_view )
+		// kile completion: is there a new cursor position?
+		if ( m_kilecompletion && m_setcursor && ( m_xoffset != 0 || m_yoffset != 0 ) && m_view )
 		{
 			int newx = ( m_xoffset != 0 ) ? m_xcursor + m_xoffset - m_textlen : m_xcursor;
 			int newy = ( m_yoffset != 0 ) ? m_ycursor + m_yoffset : m_ycursor;
@@ -307,6 +490,7 @@ namespace KileDocument
 
 	void CodeCompletion::CompletionAborted()
 	{
+		// aborted: undo if kile completion is active
 		if ( m_inprogress && m_undo && m_view )
 		{
 			uint row, col;
@@ -326,19 +510,20 @@ namespace KileDocument
 
 	//////////////////// build the text for completion ////////////////////
 
-	// parse an entry:
+	// parse an entry for kile completion modes:
 	// - delete arguments/parameters
 	// - set cursor position
 	// - insert bullets
 
 	QString CodeCompletion::filterCompletionText( const QString &text, const QString &type )
 	{
-    static QRegExp::QRegExp reEnv = QRegExp("^\\\\(begin|end)[^a-zA-Z]+");
-		kdDebug() << "   complete filter: " << text << " type " << type << endl;
+		static QRegExp::QRegExp reEnv = QRegExp("^\\\\(begin|end)[^a-zA-Z]+");
+		//KILE_DEBUG() << "   complete filter: " << text << " type " << type << endl;
 		m_type = getType( text );    // remember current type
-    
-    if ( reEnv.search(text) != -1 ) m_mode = cmEnvironment;
-    
+
+		if ( text!="\\begin{}" && reEnv.search(text)!=-1 )
+			m_mode = cmEnvironment;
+
 		// check the cursor position, because the user may have
 		// typed some characters or the backspace key. This also
 		// changes the length of the current pattern.
@@ -354,21 +539,44 @@ namespace KileDocument
 		m_xoffset = m_yoffset = 0;
 
 		// build the text
-		QString s;
-		Kate::Document *doc;
+		QString s,prefix;
+		Kate::Document *doc = m_view->getDoc();
+		QString textline = doc->textLine(row);
 		switch ( m_mode )
 		{
 				case cmLatex:
-  			s = buildLatexText( text, m_yoffset, m_xoffset );
+				s = buildLatexText( text, m_yoffset, m_xoffset );
+				if ( m_autobrackets && textline.at(col)=='}' && m_text.find('{')>=0 )
+				{
+					doc->removeText(row,col,row,col+1);
+				}
 				break;
 				case cmEnvironment:
-				s = buildEnvironmentText( text, type, m_yoffset, m_xoffset );
-				doc = m_view->getDoc();
-				if ( m_xstart>=7 && doc->text(row,m_xstart-7,row,m_xstart) == "\\begin{" ) {
+				prefix = QString::null;
+				if ( m_autoindent )
+				{
+					if ( col-m_textlen>0 )
+					{
+						prefix = textline.left(col-m_textlen);
+						if ( prefix.right(7) == "\\begin{" )
+							prefix.truncate(prefix.length()-7);
+						else if ( prefix.right(5) == "\\end{" )
+							prefix.truncate(prefix.length()-5);
+					}
+				}
+				s = buildEnvironmentText( text, type, prefix, m_yoffset, m_xoffset );
+				if ( m_autobrackets && textline.at(col)=='}' && (textline[m_xstart]!='\\' || m_text.find('{')>=0 ) )
+				{
+					doc->removeText(row,col,row,col+1);
+				}
+				if ( m_xstart>=7 && textline.mid(m_xstart-7,7) == "\\begin{" )
+				{
 					m_textlen += 7;
-				} else if ( m_xstart>=5 && doc->text(row,m_xstart-5,row,m_xstart) == "\\end{" ) {
+				}
+				else if ( m_xstart>=5 && textline.mid(m_xstart-5,5) == "\\end{" )
+				{
 					m_textlen += 5;
-				} 
+				}
 				break;
 				case cmDictionary:
 				s = text;
@@ -378,13 +586,18 @@ namespace KileDocument
 				break;
 				case cmLabel:
 				s = buildLabelText( text );
+				if ( m_keylistType==CodeCompletion::ctReference
+				     || (m_keylistType==CodeCompletion::ctCitation && m_citationMove) )
+				{
+					m_xoffset = s.length() + 1;
+				}
 				break;
 				case cmDocumentWord:
 				s = text;
 				break;
         default : s = text; break;
 		}
-		
+
 		if ( s.length() > m_textlen )
 			return s.right( s.length() - m_textlen );
 		else
@@ -401,62 +614,65 @@ namespace KileDocument
 	////////////////////  text in cmEnvironment mode ////////////////////
 
 	QString CodeCompletion::buildEnvironmentText( const QString &text, const QString &type,
-	        uint &ypos, uint &xpos )
+	                                              const QString &prefix, uint &ypos, uint &xpos )
 	{
-    static QRegExp::QRegExp reEnv = QRegExp("^\\\\(begin|end)\\{([^\\}]*)\\}(.*)");
-    
-    if (reEnv.search(text) == -1) return text;
-    
-    QString parameter = stripParameter( reEnv.cap(3) );
-    QString start = reEnv.cap(1);
-    QString envname = reEnv.cap(2);
-    QString whitespace = getWhiteSpace();
-    
-    QString s = "\\" + start + "{" + envname + "}" + parameter + "\n";
-    
-    s += whitespace;
-    
-    bool item = (type == "list" );
-    if ( item )
+		static QRegExp::QRegExp reEnv = QRegExp("^\\\\(begin|end)\\{([^\\}]*)\\}(.*)");
+
+		if (reEnv.search(text) == -1) return text;
+
+		QString parameter = stripParameter( reEnv.cap(3) );
+		QString start = reEnv.cap(1);
+		QString envname = reEnv.cap(2);
+		QString whitespace = getWhiteSpace(prefix);
+		QString envIndent = m_ki->editorExtension()->autoIndentEnvironment();
+
+		QString s = "\\" + start + "{" + envname + "}" + parameter + "\n";
+
+		s += whitespace;
+		if ( start != "end" )
+			s += envIndent;
+
+		bool item = (type == "list" );
+		if ( item )
 			s += "\\item ";
-      
-    if ( m_setbullets && !parameter.isEmpty() )
-		s += s_bullet;
-      
-    if ( m_closeenv && start != "end" )
-			s += "\n" + whitespace + "\\end{" + envname + "}\n";
-    
-    // place cursor
+
+		if ( m_setbullets && !parameter.isEmpty() )
+			s += s_bullet;
+
+		if ( m_closeenv && start != "end" )
+			s += '\n' + whitespace + "\\end{" + envname + "}\n";
+
+		// place cursor
 		if ( m_setcursor )
 		{
 			if ( parameter.isEmpty() )
 			{
 				ypos = 1;
-				xpos = whitespace.length() + (( item ) ? 6 : 0);
+				xpos = whitespace.length() + envIndent.length() + (( item ) ? 6 : 0);
 			}
 			else
 			{
 				ypos = 0;
-				xpos = 9 + envname.length();
+				if( parameter.left(2) == "[<" )
+					xpos = 10 + envname.length();
+				else
+					xpos = 9 + envname.length();
 			}
 		}
-    
-    return s;
+
+		return s;
+	}
+
+	QString CodeCompletion::getWhiteSpace(const QString &s)
+	{
+		QString whitespace = s;
+		for ( uint i=0; i<whitespace.length(); ++i )
+		{
+			if ( ! whitespace[i].isSpace() )
+				whitespace[i] = ' ';
+		}
+		return whitespace;
 	}
-    
-    QString CodeCompletion::getWhiteSpace()
-    {
-        QString line = m_view->getDoc()->textLine(m_view->cursorLine());
-        QString whitespace = QString::null;
-        int i = 0;
-        while ( line[i].isSpace() )
-        {
-            whitespace += line[i];
-            ++i;
-        }
-            
-        return whitespace;
-    }
 
 	//////////////////// text in  cmAbbreviation mode ////////////////////
 
@@ -516,22 +732,30 @@ namespace KileDocument
 		{
 			switch ( text[ i ] )
 			{
+					case '<':
 					case '{':
 					case '(':
-					case '[':                    // insert character
+					case '[':		// insert character
 					s += text[ i ];
 					if ( xpos == 0 )
 					{
 						// remember position after first brace
-						xpos = i + 1;
+						if(text[i] == '[' && (i+1) < text.length() &&  text[i+1] == '<'){
+							xpos = i + 2;
+							s += text[i+1];
+							i++;
+						}// special handling for '[<'
+						else
+							xpos = i + 1;
 						// insert bullet, if this is no cursorposition
-						if ( ( ! m_setcursor ) && m_setbullets )
+						if ( ( ! m_setcursor ) && m_setbullets && !( text[i] == '[' && (i+1) < text.length() &&  text[i+1] == '<' ))
 							s += s_bullet;
 					}
 					// insert bullets after following braces
-					else if ( m_setbullets )
+					else if ( m_setbullets && !( text[i] == '[' && (i+1) < text.length() &&  text[i+1] == '<' ) )
 						s += s_bullet;
 					break;
+					case '>':
 					case '}':
 					case ')':
 					case ']':                    // insert character
@@ -550,9 +774,9 @@ namespace KileDocument
 						foundgroup = true;
 						s.truncate( s.length() - 1 );
 						if ( m_setbullets )
-							s += " " + s_bullet + " ";
+							s += ' ' + s_bullet + ' ';
 						else
-							s += " ";
+							s += ' ';
 					}
 					else
 						s += text[ i ];
@@ -607,7 +831,8 @@ namespace KileDocument
 		return s;
 	}
 
-	// astrip all names enclosed in braces
+	// strip all names enclosed in braces
+	// consider also beamer like stuff [<...>] and <...>
 
 	QString CodeCompletion::stripParameter( const QString &text )
 	{
@@ -615,19 +840,22 @@ namespace KileDocument
 		const QChar *ch = text.unicode();
 		bool ignore = false;
 
+
 		for ( uint i = 0; i < text.length(); ++i )
 		{
 			switch ( *ch )
 			{
+					case '[':
 					case '{':
 					case '(':
-					case '[':
+					case '<':
 					s += *ch;
 					ignore = true;
 					break;
+					case ']':
 					case '}':
 					case ')':
-					case ']':
+					case '>':
 					s += *ch;
 					ignore = false;
 					break;
@@ -646,9 +874,11 @@ namespace KileDocument
 
 	//////////////////// read wordlists  ////////////////////
 
-	void CodeCompletion::readWordlist( QStringList &wordlist, const QString &filename )
+	void CodeCompletion::readWordlist( QStringList &wordlist, const QString &filename, bool global )
 	{
-		QString file = KGlobal::dirs() ->findResource( "appdata", "complete/" + filename );
+		QString file = ( global )
+		             ? KGlobal::dirs()->findResource( "appdata", "complete/" + filename )
+		             : m_localAbbrevFile;
 		if ( file.isEmpty() ) return;
 
 		QFile f( file );
@@ -668,18 +898,81 @@ namespace KileDocument
 	}
 
 	void CodeCompletion::setCompletionEntries( QValueList<KTextEditor::CompletionEntry> *list,
-	        const QStringList &wordlist )
+	                                           const QStringList &wordlist )
 	{
-		// clear the whole list
+		// clear the list of completion entries
 		list->clear();
 
 		KTextEditor::CompletionEntry e;
+		QStringList::ConstIterator it;
 
-		// build new entries: if the last 5 chars of an environment are '\item',
-		// it is a list environment, where the '\item' tag is also inserted
-		for ( uint i = 0; i < wordlist.count(); ++i )
+		// build new entries
+		for ( it=wordlist.begin(); it != wordlist.end(); ++it )
 		{
-			QString s = wordlist[ i ];
+			// set CompletionEntry
+			e.text = *it;
+			e.type = "";
+
+			// add new entry
+			if ( list->findIndex(e) == -1 )
+				list->append(e);
+		}
+	}
+
+	void CodeCompletion::setCompletionEntriesTexmode( QValueList<KTextEditor::CompletionEntry> *list,
+	        const QStringList &wordlist )
+	{
+		// clear the list of completion entries
+		list->clear();
+
+		// create a QMap for a user defined sort
+		// order: \abc, \abc[], \abc{}, \abc*, \abc*[], \abc*{}, \abcd, \abcD
+		QStringList keylist;
+		QMap<QString,QString> map;
+
+		for ( uint i=0; i< wordlist.count(); ++i )
+		{
+			QString s = wordlist[i];
+			for ( uint j=0; j<s.length(); ++j )
+			{
+				QChar ch = s[j];
+				if ( ch>='A' && ch<='Z' )
+					s[j] = (int)ch + 32 ;
+				else if ( ch>='a' && ch<='z' )
+					s[j] = (int)ch - 32 ;
+				else if ( ch == '}' )
+					s[j] = 48;
+				else if ( ch == '{' )
+					s[j] = 49;
+				else if ( ch == '[' )
+					s[j] = 50;
+				else if ( ch == '*' )
+					s[j] = 51;
+				else if ( ch == ']' )
+					s[j] = 52;
+			}
+			// don't allow duplicate entries
+			if ( ! map.contains(s) )
+			{
+				map[s] = wordlist[i];
+				keylist.append(s);
+			}
+		}
+
+		// sort mapped keys
+		keylist.sort();
+
+		// build new entries: get the sorted keys and insert
+		// the real entries, which are saved in the map.
+		// if the last 5 chars of an environment are '\item', it is a
+		// list environment, where the '\item' tag is also inserted
+		KTextEditor::CompletionEntry e;
+		QStringList::ConstIterator it;
+
+		for ( it=keylist.begin(); it != keylist.end(); ++it )
+		{
+			// get real entry
+			QString s = map[*it];
 			if ( s.left( 7 ) == "\\begin{" && s.right( 5 ) == "\\item" )
 			{
 				e.text = s.left( s.length() - 5 );     // list environment entry
@@ -690,9 +983,8 @@ namespace KileDocument
 				e.text = s;                        // normal entry
 				e.type = "";
 			}
-			// add new entry
-			if ( list->findIndex(e) == -1 )
-				list->append(e);
+			// add new entry (duplicates are impossible)
+			list->append(e);
 		}
 	}
 
@@ -722,6 +1014,21 @@ namespace KileDocument
 		return n;
 	}
 
+	QString CodeCompletion::findExpansion(const QString &abbrev)
+	{
+		QValueList<KTextEditor::CompletionEntry>::Iterator it;
+
+		for ( it=m_abbrevlist.begin(); it!=m_abbrevlist.end(); ++it )
+		{
+			QString s = (*it).text;
+			int index = s.find("=");
+			if ( index>=0 && s.left(index)==abbrev )
+				 return s.right( s.length()-index-1 );
+		}
+
+		return QString::null;
+	}
+
 	void CodeCompletion::editComplete(Kate::View *view, Mode mode)
 	{
 		m_view = view;
@@ -729,6 +1036,19 @@ namespace KileDocument
 		if ( !m_view || !isActive() || inProgress() )
 			return ;
 
+		// check for a special case: call from inside of a reference command
+		if ( mode==cmLatex )
+		{
+			QString startpattern;
+			CodeCompletion::Type reftype = insideReference(startpattern);
+			if ( reftype != CodeCompletion::ctNone )
+			{
+				m_ref = true;
+				editCompleteList(reftype,startpattern);
+				return;
+			}
+		}
+
 		QString word;
 		Type type;
 		if ( getCompleteWord(( mode == cmLatex ) ? true : false, word, type ) )
@@ -738,7 +1058,7 @@ namespace KileDocument
 				mode = cmDictionary;
 			}
 
-			if ( type == ctNone )
+			if ( type == CodeCompletion::ctNone )
 				completeWord(word, mode);
 			else
 				editCompleteList(type);
@@ -755,81 +1075,122 @@ namespace KileDocument
 		}
 	}
 
-	void CodeCompletion::editCompleteList(Type type )
+	void CodeCompletion::editCompleteList(Type type,const QString &pattern)
 	{
-		kdDebug() << "==editCompleteList=============" << endl;
+		//KILE_DEBUG() << "==editCompleteList=============" << endl;
+		m_keylistType = type;
 		if ( type == ctReference )
-			completeFromList(info()->allLabels());
+			completeFromList(info()->allLabels(),pattern);
 		else if ( type == ctCitation )
-			completeFromList(info()->allBibItems());
-    else
-      kdWarning() << "unsupported type in CodeCompletion::editCompleteList" << endl;
+			completeFromList(info()->allBibItems(),pattern);
+		else
+		{
+			m_keylistType = CodeCompletion::ctNone;
+			kdWarning() << "unsupported type in CodeCompletion::editCompleteList" << endl;
+		}
 	}
 
 	//////////////////// slots for code completion ////////////////////
 
 	void CodeCompletion::slotCompletionDone(KTextEditor::CompletionEntry entry)
 	{
-		kdDebug() << "==slotCompletionDone=============" << endl;
+		//KILE_DEBUG() << "==slotCompletionDone (" << m_kilecompletion << "," << m_inprogress << ")=============" << endl;
 		CompletionDone(entry);
 
-		if ( getMode() == cmLatex ) m_completeTimer->start( 10, true );
-		
-		if ( KileConfig::completeAuto() && ( (entry.text.find(reRef) != -1) || (entry.text.find(reCite) != -1) ) ) 
+		// if kile completion was active, look if we need to show an additional list
+		if ( m_kilecompletion )
 		{
-			m_ref = true;
-			completeWord("", cmLabel);
+			m_kilecompletion = false;
+			if ( getMode() == cmLatex )
+			{
+				m_type = getType(entry.text);
+				if ( (m_type==CodeCompletion::ctReference && info()->allLabels()->count()>0)  ||
+					  (m_type==CodeCompletion::ctCitation  && info()->allBibItems()->count()>0) )
+				{
+					m_keylistType = m_type;
+					m_ref = true;
+		 			m_completeTimer->start(20,true);
+				}
+			}
 		}
-		else
-			m_view = 0L;
 	}
 
 	void CodeCompletion::slotCompleteValueList()
 	{
-		kdDebug() << "==slotCompleteValueList=============" << endl;
+		//KILE_DEBUG() << "==slotCompleteValueList (" << m_kilecompletion << "," << m_inprogress << ")=============" << endl;
 		m_completeTimer->stop();
 		editCompleteList(getType());
 	}
 
 	void CodeCompletion::slotCompletionAborted()
 	{
-		kdDebug() << "==slotCompletionAborted=============" << endl;
+		//KILE_DEBUG() << "==slotCompletionAborted (" << m_kilecompletion << "," << m_inprogress << ")=============" << endl;
 		CompletionAborted();
 	}
 
 	void CodeCompletion::slotFilterCompletion( KTextEditor::CompletionEntry* c, QString *s )
 	{
-		kdDebug() << "==slotFilterCompletion=============" << endl;
-		if ( inProgress() ) {                // dani 28.09.2004
-			kdDebug() << "\tin progress: s=" << *s << endl;
+		//KILE_DEBUG() << "==slotFilterCompletion (" << m_kilecompletion << "," << m_inprogress << ")=============" << endl;
+		if ( inProgress() )                 // dani 28.09.2004
+		{
+			//KILE_DEBUG() << "\tin progress: s=" << *s << endl;
 			*s = filterCompletionText( c->text, c->type );
-			kdDebug() << "\tfilter --->" << *s << endl;
+			//KILE_DEBUG() << "\tfilter --->" << *s << endl;
 			m_inprogress = false;
+			m_kilecompletion = true;
 		}
 	}
 
 	void CodeCompletion::slotCharactersInserted(int, int, const QString& string )
 	{
+		//KILE_DEBUG() << "==slotCharactersInserted (" << m_kilecompletion << "," << m_inprogress << ", " << m_ref << ", " << string << ")=============" << endl;
+
+		if ( !inProgress() && m_autoDollar && string=="$" )
+		{
+			autoInsertDollar();
+			return;
+		}
+
+		// only work, if autocomplete mode of Kile is active
 		if ( !isActive() || !autoComplete() )
 			return ;
 
 		//FIXME this is not very efficient
-		m_view = info()->viewManager()->currentView();
-		
+		m_view = info()->viewManager()->currentTextView();
+
+		// try to autocomplete abbreviations after punctuation symbol
+		if ( !inProgress() && m_autocompleteabbrev && completeAutoAbbreviation(string) )
+			return;
+
+		// rather unsusual, but it may happen: the cursor is inside
+		// of a reference command without a labellist.
+		if ( ! m_ref )
+		{
+			QString startpattern;
+			CodeCompletion::Type reftype = insideReference(startpattern);
+			if ( reftype != CodeCompletion::ctNone )
+			{
+				m_ref = true;
+				editCompleteList(reftype,startpattern);
+				return;
+			}
+		}
+
 		QString word;
 		Type type;
-		bool found = ( m_ref ) ? getReferenceWord(word) : getCompleteWord(true,word,type ); 
-		if ( found ) { 
+		bool found = ( m_ref ) ? getReferenceWord(word) : getCompleteWord(true,word,type );
+		if ( found )
+		{
 			int wordlen = word.length();
-			kdDebug() << "   auto completion: word=" << word << " mode=" << m_mode << " inprogress=" << inProgress() << endl;
+			//KILE_DEBUG() << "   auto completion: word=" << word << " mode=" << m_mode << " inprogress=" << inProgress() << endl;
 			if ( inProgress() )               // continue a running mode?
 			{
-				kdDebug() << "   auto completion: continue current mode" << endl;
-				completeWord(word, m_mode);     
+				//KILE_DEBUG() << "   auto completion: continue current mode" << endl;
+				completeWord(word, m_mode);
 			}
 			else if ( word.at( 0 )=='\\' && m_autocomplete && wordlen>=m_latexthreshold)
 			{
-				kdDebug() << "   auto completion: latex mode" << endl;
+				//KILE_DEBUG() << "   auto completion: latex mode" << endl;
 				if ( string.at( 0 ).isLetter() )
 				{
 					completeWord(word, cmLatex);
@@ -838,10 +1199,10 @@ namespace KileDocument
 				{
 					editCompleteList(type);
 				}
-			} 
-			else if ( word.at(0).isLetter() && m_autocompletetext && wordlen>=m_textthreshold) 
+			}
+			else if ( word.at(0).isLetter() && m_autocompletetext && wordlen>=m_textthreshold)
 			{
-				kdDebug() << "   auto completion: document mode" << endl;
+				//KILE_DEBUG() << "   auto completion: document mode" << endl;
 				completeWord(word,cmDocumentWord);
 			}
 		}
@@ -879,7 +1240,7 @@ namespace KileDocument
 			// get current character
 			ch = textline.at( index );
 
-			if ( ch.isLetter() || ( latexmode && ( index + 1 == ( int ) col ) && ch == '{' ) )
+			if ( ch.isLetter() || ch=='.' || ch == '_' || ch.isDigit() || ( latexmode && ( index + 1 == ( int ) col ) && ch == '{' ) )
 				++n;                           // accept letters and '{' as first character in latexmode
 			else
 			{
@@ -912,30 +1273,30 @@ namespace KileDocument
 		// get current text line
 		QString textline = m_view->getDoc()->textLine( row );
 
-		// search the current reference string 
+		// search the current reference string
 		int pos = textline.findRev(reNotRefChars,col-1);
 		if ( pos < 0 )
 			pos = 0;
-			
+
 		// select pattern
 		text = textline.mid(pos+1,col-1-pos);
 		return ( (uint)pos < col-1 );
 	}
-	
+
 	void CodeCompletion::getDocumentWords(const QString &text,
 	                                      QValueList<KTextEditor::CompletionEntry> &list)
 	{
-		//kdDebug() << "getDocumentWords: " << endl;
+		//KILE_DEBUG() << "getDocumentWords: " << endl;
 		list.clear();
-		
-		QRegExp reg("(\\\\?\\b" + QString(text[0]) + "[^\\W\\d_]+)\\b");          
+
+		QRegExp reg("(\\\\?\\b" + QString(text[0]) + "[^\\W\\d_]+)\\b");
 		Kate::Document *doc = m_view->getDoc();
-		
+
 		QString s;
 		KTextEditor::CompletionEntry e;
-		QDict<bool> seen; 
+		QDict<bool> seen;
 		bool alreadyseen = true;
-		               
+
 		for (uint i=0; i<doc->numLines(); ++i) {
 			s = doc->textLine(i);
 			int pos = 0;
@@ -966,6 +1327,129 @@ namespace KileDocument
 		}
 		return ( n % 2 ) ? true : false;
 	}
+
+	//////////////////// complete auto abbreviation ////////////////////
+
+	bool CodeCompletion::completeAutoAbbreviation(const QString &text)
+	{
+		if ( text.length() != 1 )
+			return false;
+
+		QChar ch = text[0];
+		if ( ! (ch.isSpace() || ch.isPunct()) )
+			return false;
+
+		uint row,col;
+		m_view->cursorPositionReal( &row, &col );
+		QString abbrev = getAbbreviationWord(row,col-1);
+		if ( abbrev.isEmpty() )
+			return false;
+
+		QString expansion = findExpansion(abbrev);
+		if ( expansion.isEmpty() )
+			return false;
+
+		KILE_DEBUG() << "=== CodeCompletion::completeAutoAbbreviation: abbrev=" << abbrev << "  exp=" << expansion << endl;
+
+		uint len = abbrev.length();
+		uint startcol = col - len - 1;
+		Kate::Document *doc = m_view->getDoc();
+		doc->removeText( row,startcol,row,startcol+abbrev.length()+1 );
+		doc->insertText( row,startcol,expansion+ch);
+		m_view->setCursorPositionReal( row,startcol+expansion.length()+1 );
+
+		return true;
+	}
+
+	QString CodeCompletion::getAbbreviationWord(uint row, uint col)
+	{
+		QString textline = m_view->getDoc()->textLine( row );
+
+		int index = (int)col;
+		while ( --index >= 0 )
+		{
+			QChar ch = textline.at( index );
+			if ( ! ch.isLetterOrNumber() )
+				break;
+		}
+
+		return textline.mid(index+1,col-index-1);
+	}
+
+	//////////////////// connection with the abbreviation listview  ////////////////////
+
+	void CodeCompletion::setAbbreviationListview(KileAbbrevView *listview)
+	{
+		m_abbrevListview = listview;
+
+		connect( m_abbrevListview, SIGNAL(updateAbbrevList(const QString &, const QString &)),
+		         this, SLOT(slotUpdateAbbrevList(const QString &, const QString &)) );
+
+	}
+
+	void CodeCompletion::slotUpdateAbbrevList(const QString &ds, const QString &as)
+	{
+		if ( ! ds.isEmpty() )
+		{
+			deleteAbbreviationEntry(ds);
+		}
+		if ( ! as.isEmpty() )
+		{
+			addAbbreviationEntry(as);
+		}
+	}
+
+	void CodeCompletion::deleteAbbreviationEntry( const QString &entry )
+	{
+		KILE_DEBUG() << "=== CodeCompletion::deleteAbbreviationEntry (" << entry << ")" << endl;
+		QValueList<KTextEditor::CompletionEntry>::Iterator it;
+		for ( it=m_abbrevlist.begin(); it!=m_abbrevlist.end(); ++it )
+		{
+			if ( (*it).text == entry )
+			{
+				m_abbrevlist.remove( it );
+				return;
+			}
+		}
+	}
+
+	void CodeCompletion::addAbbreviationEntry( const QString &entry )
+	{
+		KILE_DEBUG() << "=== CodeCompletion::addAbbreviationEntry (" << entry << ")" << endl;
+		QValueList<KTextEditor::CompletionEntry>::Iterator it;
+		for ( it=m_abbrevlist.begin(); it!=m_abbrevlist.end(); ++it )
+		{
+			if ( (*it).text > entry )
+				break;
+		}
+
+		KTextEditor::CompletionEntry e;
+		e.text = entry;
+		e.type = QString::null;
+
+		if ( it == m_abbrevlist.begin() )
+			m_abbrevlist.prepend(e);
+		else if ( it == m_abbrevlist.end() )
+			m_abbrevlist.append(e);
+		else
+			m_abbrevlist.insert(it,e);
+	}
+
+	//////////////////// autoinsert $ ////////////////////
+
+	void CodeCompletion::autoInsertDollar()
+	{
+		Kate::View *view = info()->viewManager()->currentTextView();
+		if ( view )
+		{
+			uint row,col;
+			view = info()->viewManager()->currentTextView();
+			view->cursorPositionReal( &row, &col );
+			view->getDoc()->insertText(row,col,"$");
+			view->setCursorPositionReal( row, col );
+		}
+	}
+
 }
 
 #include "codecompletion.moc"
