@@ -29,7 +29,7 @@
 #include <kfiledialog.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
-#include <kdebug.h>
+#include "kiledebug.h"
 #include <kpushbutton.h>
 #include <kprocess.h>
 #include <klineedit.h>
@@ -232,19 +232,19 @@ QString IncludeGraphics::getTemplate()
 	// add some options
 	QString options = getOptions();
 	if ( !options.isEmpty() )
-		s += "[" + options + "]";
+		s += '[' + options + ']';
  
 	// add name of picture
 	// either take the filename or try to take the relative part of the name
 	QString filename = ( cb_graphicspath->isChecked() ) 
 	                 ? QFileInfo(edit_file->text()).fileName() 
 	                 : m_ki->relativePath(QFileInfo(m_ki->getCompileName()).dirPath(), edit_file->text());
-	s += "{" + filename + "}\n";
+	s += '{' + filename + "}\n";
  
 	// add some comments (depending of given resolution, this may be wrong!)
 	QString info = getInfo();
 	if (info.length() > 0) 
-		s += indent + info + "\n";
+		s += indent + info + '\n';
 
 	// close center environment ? 
 	if ( center && !figure )
@@ -310,10 +310,10 @@ QString IncludeGraphics::getInfo()
 	{
 		QFileInfo fi( edit_file->text() );
 
-		return "% " + fi.baseName() + "." + fi.extension(true)
+		return "% " + fi.baseName() + '.' + fi.extension(true)
 		            + QString(": %1x%2 pixel").arg(wpx).arg(hpx)
 		            + ", " + dpi + "dpi"
-		            + ", " + wcm + "x" + hcm + " cm"
+		            + ", " + wcm + 'x' + hcm + " cm"
 		            + ", bb=" + edit_bb->text();
 	}
 }
@@ -327,7 +327,7 @@ void IncludeGraphics::setInfo()
 	if ( !edit_file->text().isEmpty() && getPictureSize(wpx,hpx,dpi,wcm,hcm) ) 
 	{
 		text = QString("%1x%2 pixel").arg(wpx).arg(hpx)
-			       + " / " + wcm + "x" + hcm + " cm"
+			       + " / " + wcm + 'x' + hcm + " cm"
 			       + "  (" + dpi + "dpi)";
 	} 
 	else
@@ -390,8 +390,8 @@ void IncludeGraphics::chooseFile()
       else
          execute( "identify -format \"w=%w h=%h dpi=%x\" " + fn);
    } else {
-      kdDebug() << "=== IncludeGraphics::error ====================" << endl;
-      kdDebug() << "   filename: '" << fn << "'" << endl;
+      KILE_DEBUG() << "=== IncludeGraphics::error ====================" << endl;
+      KILE_DEBUG() << "   filename: '" << fn << "'" << endl;
    }
 }
 
@@ -415,8 +415,8 @@ void IncludeGraphics::execute(const QString &command)
            this, SLOT(slotProcessExited(KProcess*)) );
 
    m_output = "";
-   kdDebug() << "=== IncludeGraphics::execute ====================" << endl;
-   kdDebug() << "   execute '" << command << "'" << endl;
+   KILE_DEBUG() << "=== IncludeGraphics::execute ====================" << endl;
+   KILE_DEBUG() << "   execute '" << command << "'" << endl;
 
    m_proc->start(KProcess::NotifyOnExit, KProcess::AllOutput);
 }
@@ -433,7 +433,7 @@ void IncludeGraphics::slotProcessOutput(KProcess*,char* buffer,int buflen)
 void IncludeGraphics::slotProcessExited(KProcess* proc)
 {
   if ( proc->normalExit() &&  !proc->exitStatus() ) {
-      kdDebug() << "   result: " << m_output << endl;
+      KILE_DEBUG() << "   result: " << m_output << endl;
 
       // set the default resolution
       m_resolution = m_defaultresolution;
@@ -482,7 +482,7 @@ void IncludeGraphics::slotProcessExited(KProcess* proc)
 
 	// take width and height as parameters for the bounding box
 	 edit_bb->setText( QString("0 0 ") + QString("%1").arg(bbw)
-	                                   + " "
+	                                   + ' '
 	                                   + QString("%1").arg(bbh)
 	                  );
 
