@@ -1,7 +1,9 @@
 /***************************************************************************
     begin                : Wed Jun 6 2001
     copyright            : (C) 2003 by Jeroen Wijnhout
+                           (C) 2005-2007  by Holger Danielsson
     email                : Jeroen.Wijnhout@kdemail.net
+                           holger.danielsson@versanet.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,6 +23,12 @@
 //  - geometry of the dialog are saved and restored, because
 //    the initial values may be bad in some languages
 
+// 2007-03-17 dani
+//  - add support for auto insert $
+//  - move graphics config to a separate page
+
+#include "kileconfigdialog.h"
+
 #include <qvbox.h>
 #include <qlayout.h>
 #include <qtextcodec.h>
@@ -32,17 +40,17 @@
 
 #include "kiletoolmanager.h"
 #include "kiletoolconfigwidget.h"
-#include "kileconfigdialog.h"
 #include "kileviewmanager.h"
 #include "helpconfigwidget.h"
 #include "latexconfigwidget.h"
 #include "generalconfigwidget.h"
 #include "previewconfigwidget.h"
+#include "scriptingconfigwidget.h"
 #include "kileconfig.h"
 #include "kileinfo.h"
 #include "kileedit.h"
 
-#include <kdebug.h>
+#include "kiledebug.h"
 
 namespace KileDialog
 {
@@ -67,10 +75,13 @@ namespace KileDialog
 		setupGeneralOptions();
 		setupCodeCompletion();   // complete configuration (dani)
 		setupHelp();
+		setupScripting();
 
 		setupLatex();
 		setupEnvironment();
+		setupGraphics();
 		setupStructure();
+		setupSymbolView();
 
 		setupTools();
 		setupQuickPreview();     // QuickPreview (dani)
@@ -124,7 +135,7 @@ namespace KileDialog
 	                           const QString &pixmapName, const QString &header,
 	                           bool addSpacer)
 	{
-		kdDebug() << "slot: add config page item=" << itemName << endl;
+		KILE_DEBUG() << "slot: add config page item=" << itemName << endl;
 
 		// add page
 		QStringList path;
@@ -167,13 +178,21 @@ namespace KileDialog
 		addConfigPage(toolPage,i18n("Tools"),i18n("Build"),"launch",i18n("Build"),false);
 	}
 
+	//////////////////// Scripting  ////////////////////
+
+	void Config::setupScripting()
+	{
+		scriptingPage = new KileWidgetScriptingConfig(this, "Scripting");
+		addConfigPage(scriptingPage,i18n("Kile"),i18n("Scripting"),"exec",i18n("Scripting Support"));
+	}
+
 	//////////////////// LaTeX specific editing options ////////////////////
 
 	//////////////////// Complete configuration (dani) ////////////////////
 
 	void Config::setupCodeCompletion()
 	{
-		completePage = new ConfigCodeCompletion(m_config);
+		completePage = new ConfigCodeCompletion(m_config,m_ki->logWidget());
 		completePage->readConfig();
 
 		addConfigPage(completePage,i18n("Kile"),i18n("Complete"),"source",i18n("Code Completion"));
@@ -211,7 +230,15 @@ namespace KileDialog
 	void Config::setupEnvironment()
 	{
 		envPage = new KileWidgetEnvironmentConfig(0, "LaTeX");
-      addConfigPage(envPage,i18n("LaTeX"),i18n("Environments"),"environment");
+		addConfigPage(envPage,i18n("LaTeX"),i18n("Environments"),"environment");
+	}
+
+	void Config::setupGraphics()
+	{
+		graphicsPage = new KileWidgetGraphicsConfig(0, "Graphics");
+		graphicsPage->m_lbImagemagick->setText( ( KileConfig::imagemagick() ) ? i18n("installed") : i18n("not installed") ); 
+
+		addConfigPage(graphicsPage,i18n("LaTeX"),i18n("Graphics"),"graphicspage");
 	}
 
 	void Config::setupStructure()
@@ -220,11 +247,17 @@ namespace KileDialog
       addConfigPage(structurePage,i18n("LaTeX"),i18n("Structure View"),"view_tree");
 	}
 
+	void Config::setupSymbolView()
+	{
+		symbolViewPage = new KileWidgetSymbolViewConfig(0, "SymbolView");
+      		addConfigPage(symbolViewPage,i18n("LaTeX"),i18n("Symbol View"),"math0");
+	}
+
 	//////////////////// Editor ////////////////////
 
 	void Config::setupEditor()
 	{
-		Kate::View *view = m_ki->viewManager()->currentView();
+		Kate::View *view = m_ki->viewManager()->currentTextView();
 		m_editorOpened = ( view != 0L );
 		m_editorSettingsChanged = false;
 
@@ -274,14 +307,14 @@ namespace KileDialog
 
 	void Config::slotOk()
 	{
-		kdDebug() << "   slot ok (" << m_manager->hasChanged() << ","  << m_editorSettingsChanged << ")" << endl;
+		KILE_DEBUG() << "   slot ok (" << m_manager->hasChanged() << ","  << m_editorSettingsChanged << ")" << endl;
 
 		// editor settings are only available, when at least one document is opened
 		if ( m_editorOpened && m_editorSettingsChanged )
 		{
 			for (uint i=0; i<editorPages.count(); i++)
 				editorPages.at(i)->apply();
- 			m_ki->viewManager()->currentView()->getDoc()->writeConfig();
+ 			m_ki->viewManager()->currentTextView()->getDoc()->writeConfig();
 			
 			// take Kate's encoding for Kile
 			syncKileEncoding();
@@ -301,21 +334,21 @@ namespace KileDialog
 
 	void Config::slotCancel()
 	{
-		kdDebug() << "   slot cancel" << endl;
+		KILE_DEBUG() << "   slot cancel" << endl;
 		m_config->rollback();
 		accept();
 	}
 
 	void Config::slotChanged()
 	{
-		kdDebug() << "   slot changed" << endl;
+		KILE_DEBUG() << "   slot changed" << endl;
 		m_editorSettingsChanged = true;
 	}
 
 /*
 void Config::slotWidgetModified()
 {
-	kdDebug() << "slot: widget modified --> " << m_manager->hasChanged()  << endl;
+	KILE_DEBUG() << "slot: widget modified --> " << m_manager->hasChanged()  << endl;
   //emit widgetModified();
 }
 */
