@@ -3,7 +3,7 @@
    Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
    Copyright (C) 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
    Copyright (C) 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
-   Copyright (C) 2005 Holger Danielsson <holgerdanielsson@t-online.de>
+   Copyright (C) 2005 Holger Danielsson <holger.danielsson@versanet.de>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -38,6 +38,9 @@
     (in other words: most parts have changed to work perfectly with Kile ...)
 */
 
+// 2007-03-12 dani
+//  - use KileDocument::Extensions
+
 #include "kilegrepdialog.h"
 
 #include <qobject.h>
@@ -64,11 +67,12 @@
 #include <kurlcompletion.h>
 #include <klineedit.h>
 #include <klistbox.h>
-#include <kdebug.h>
+#include "kiledebug.h"
 
 #include "kileconfig.h"
 #include "kileproject.h"
 #include "kiledocmanager.h"
+#include "kileextensions.h"
 
 KileGrepDialog::KileGrepDialog(QWidget *parent, KileInfo *ki, KileGrep::Mode mode, const char *name)
 	: KDialogBase (parent, name, false, QString::null, 0, Ok, false ), 
@@ -76,7 +80,7 @@ KileGrepDialog::KileGrepDialog(QWidget *parent, KileInfo *ki, KileGrep::Mode mod
 {
 	QWidget *page = new QWidget(this);
 	setMainWidget(page);
-	setWFlags( Qt::WStyle_StaysOnTop );
+	//setWFlags( Qt::WStyle_StaysOnTop );
 
 	// build dialog
 	QVBoxLayout *vbox = new QVBoxLayout( page,5,KDialog::spacingHint() );
@@ -184,7 +188,7 @@ KileGrepDialog::KileGrepDialog(QWidget *parent, KileInfo *ki, KileGrep::Mode mod
 	dir_label->setBuddy(dir_combo);
 	dir_layout->addWidget(dir_combo);
 
-	recursive_box = new QCheckBox(i18n("Scan directories recursive"), filtergroup);
+	recursive_box = new QCheckBox(i18n("Scan directories recursively"), filtergroup);
 	recursive_box->setMinimumWidth(recursive_box->sizeHint().width());
 
 	filtergrouplayout->addWidget(files_label, 2,0, AlignLeft | AlignVCenter);
@@ -323,12 +327,12 @@ KileGrepDialog::KileGrepDialog(QWidget *parent, KileInfo *ki, KileGrep::Mode mod
 	connect( this, SIGNAL(finished()), SLOT(slotFinished()) );
 
 	resize(450,sizeHint().height());
-	kdDebug() << "==KileGrepDialog (create dialog)=============================" << endl;
+	KILE_DEBUG() << "==KileGrepDialog (create dialog)=============================" << endl;
 }
 
 KileGrepDialog::~KileGrepDialog()
 {
-	kdDebug() << "==KileGrepDialog (delete dialog)=============================" << endl;
+	KILE_DEBUG() << "==KileGrepDialog (delete dialog)=============================" << endl;
 	writeConfig();
 	delete childproc;
 }
@@ -382,15 +386,13 @@ void KileGrepDialog::setupDirectory()
 {
 	setDirName( QDir::home().absPath() );
 
-	QString filter(SOURCE_EXTENSIONS);
-	filter.append(" ");
-	filter.append(PACKAGE_EXTENSIONS);
-	filter.replace(".", "*.");
-	filter.replace(" ", ",");
-	filter.append("|");
-	filter.append(i18n("TeX Files"));
-	filter.append("\n*|");
-	filter.append(i18n("All Files"));
+	// use a filter for 'find in files' dialog
+	KileDocument::Extensions *extensions = m_ki->extensions();
+	QString filter = extensions->latexDocumentFileFilter() + '\n'
+	                 + extensions->latexPackageFileFilter() + '\n'
+	                 + extensions->bibtexFileFilter() + '\n'
+	                 + extensions->metapostFileFilter() + '\n'
+	                 + "*|" + i18n("All Files");
 	setFilter(filter);
 }
 
@@ -451,7 +453,7 @@ QStringList KileGrepDialog::readList(KileGrep::List listtype)
 
 void KileGrepDialog::slotItemSelected(const QString& item)
 {
-	kdDebug() << "\tgrep: start item selected" << endl;
+	KILE_DEBUG() << "\tgrep: start item selected" << endl;
 	int pos;
 	QString filename, linenumber;
 
@@ -464,10 +466,10 @@ void KileGrepDialog::slotItemSelected(const QString& item)
 		{
 			linenumber = str.left(pos);
 			if ( m_mode == KileGrep::Project )
-				emit itemSelected(m_projectdir + "/" + filename,linenumber.toInt());
+				emit itemSelected(m_projectdir + '/' + filename,linenumber.toInt());
 			else
 				//emit itemSelected(lastSearchPaths[0] + "/" + filename,linenumber.toInt());
-				emit itemSelected(dir_combo->comboBox()->text(0) + "/" + filename,linenumber.toInt());
+				emit itemSelected(dir_combo->comboBox()->text(0) + '/' + filename,linenumber.toInt());
 		}
 	}
 }
@@ -481,14 +483,14 @@ void KileGrepDialog::startGrep()
 
 	if ( m_mode == KileGrep::Project )
 	{
-		QString command = buildProjectCommand() + " " + KProcess::quote(m_projectfiles[m_grepJobs-1]);
-		kdDebug() << "\tgrep (project): " <<  command << endl;
+		QString command = buildProjectCommand() + ' ' + KProcess::quote(m_projectfiles[m_grepJobs-1]);
+		KILE_DEBUG() << "\tgrep (project): " <<  command << endl;
 		(*childproc) << QStringList::split(' ',command);
 	}
 	else
 	{
 		QString command = buildFilesCommand();
-		kdDebug() << "\tgrep (files): " << command << endl;
+		KILE_DEBUG() << "\tgrep (files): " << command << endl;
 		(*childproc) << QStringList::split(' ', command);
 	}
 	m_grepJobs--;
@@ -513,7 +515,7 @@ void KileGrepDialog::processOutput()
 		{
 			if ( m_mode == KileGrep::Project )
 			{
-				if ( item.find(m_projectdir+"/") == 0 )
+				if ( item.find(m_projectdir + '/') == 0 )
 					resultbox->insertItem( item.mid(m_projectdir.length()+1) );
 				else
 					resultbox->insertItem(item);
@@ -616,7 +618,7 @@ QString KileGrepDialog::getShellPattern()
 {
 	QString pattern = getPattern();
 	pattern.replace("'", "'\\''");
-	return QString("'") + pattern + "'";
+	return '\'' + pattern + '\'';
 	//return KProcess::quote(pattern);
 }
 
@@ -631,18 +633,18 @@ QString KileGrepDialog::buildFilesCommand()
 		files_temp = filter_combo->currentText();
 
 	if (files_temp.right(1) != ",")
-		files_temp = files_temp + ",";
+		files_temp = files_temp + ',';
 
 	QStringList tokens = QStringList::split ( ",", files_temp, false );
 	QStringList::Iterator it = tokens.begin();
 	if (it != tokens.end())
 	{
-		files = " '" + (*it) + "'" ;
+		files = " '" + (*it) + '\'';
 		++it;
 	}
 
 	for ( ; it != tokens.end(); ++it )
-		files = files + " -o -name " + "'" + (*it) + "'";
+		files = files + " -o -name " + '\'' + (*it) + '\'';
 
 	QString shell_command;
 	shell_command += "find ";
@@ -666,7 +668,7 @@ QString KileGrepDialog::buildProjectCommand()
 
 void KileGrepDialog::slotSearch()
 {
-	kdDebug() << "\tgrep: start slot search" << endl;
+	KILE_DEBUG() << "\tgrep: start slot search" << endl;
 	slotClear ();
 
 	if ( template_combo->currentItem()<KileGrep::tmEnv && pattern_combo->currentText().isEmpty() )
@@ -678,7 +680,7 @@ void KileGrepDialog::slotSearch()
 		return;
 	}
 
-	kdDebug() << "\tgrep: start new search" << endl;
+	KILE_DEBUG() << "\tgrep: start new search" << endl;
 	QRegExp re( getPattern() );
 	if ( ! re.isValid() )
 	{
@@ -705,7 +707,7 @@ void KileGrepDialog::slotSearchFor(const QString &pattern)
 
 void KileGrepDialog::slotClear()
 {
-	//kdDebug() << "\tgrep: slot clear" << endl;
+	//KILE_DEBUG() << "\tgrep: slot clear" << endl;
 	clearGrepJobs();
 	resultbox->clear();
 	finish();
@@ -713,7 +715,7 @@ void KileGrepDialog::slotClear()
 
 void KileGrepDialog::slotClose()
 {
-	//kdDebug() << "\tgrep: slot close" << endl;
+	//KILE_DEBUG() << "\tgrep: slot close" << endl;
 	clearGrepJobs();
 	finish();
 	delayedDestruct();
@@ -721,7 +723,7 @@ void KileGrepDialog::slotClose()
 
 void KileGrepDialog::slotFinished()
 {
-	//kdDebug() << "\tgrep: slot finished" << endl;
+	//KILE_DEBUG() << "\tgrep: slot finished" << endl;
 	finish();
 	delayedDestruct();
 }
@@ -875,7 +877,7 @@ QString KileGrepDialog::getCommandList(KileDocument::CmdAttribute attrtype)
 	QString commands = QString::null;
 	for ( it=cmdlist.begin(); it != cmdlist.end(); ++it ) 
 	{
-		commands += "|" + (*it).mid(1);
+		commands += '|' + (*it).mid(1);
 	}
 	return commands;
 }
