@@ -1,8 +1,10 @@
 /***************************************************************************
     begin                : Fri Aug 1 2003
     copyright            : (C) 2003 by Jeroen Wijnhout
+                         : (C) 2007  by Holger Danielsson
     email                : Jeroen.Wijnhout@kdemail.net
- ***************************************************************************/
+                           holger.danielsson@versanet.de
+***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
@@ -12,21 +14,30 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+
+// 2007-03-12 dani
+//  - use KileDocument::Extensions
+//  - allowed extensions are always defined as list, f.e.: .tex .ltx .latex 
+
 #include "kileproject.h"
 #include "kileversion.h"
 
 #include <qstringlist.h>
 #include <qfileinfo.h>
+#include <qdir.h>
 
 #include <ksimpleconfig.h>
 #include <klocale.h>
 #include <kglobal.h>
-#include <kdebug.h>
+#include "kiledebug.h"
 #include <kmessagebox.h>
 
 #include "kiledocumentinfo.h"
+#include "kiledocmanager.h"
 #include "kiletoolmanager.h"
-
+#include "kileinfo.h"
+#include "kileextensions.h"
+#include <krun.h>
 /*
  01/24/06 tbraun
 	Added the logic to get versioned kilepr files
@@ -45,14 +56,21 @@ KileProjectItem::KileProjectItem(KileProject *project, const KURL & url, int typ
 	m_parent(0L),
 	m_child(0L),
 	m_sibling(0L),
-	m_nLine(0)
+	m_nLine(0),
+	m_order(-1)
 {
-	m_highlight=m_encoding=QString::null; m_bOpen = m_archive = true;
+	m_highlight=m_encoding=QString::null;
+	m_bOpen = m_archive = true;
 
 	if (project)
 		project->add(this);
 }
 
+void KileProjectItem::setOrder(int i)
+{
+	m_order = i;
+}
+
 void KileProjectItem::setParent(KileProjectItem * item)
 {
 	m_parent = item;
@@ -83,7 +101,7 @@ void KileProjectItem::print(int level)
 {
 	QString str;
 	str.fill('\t', level);
-	kdDebug() << str << "+" << url().fileName() << endl;
+	KILE_DEBUG() << str << "+" << url().fileName() << endl;
 
 	if (firstChild())
 		firstChild()->print(++level);
@@ -96,57 +114,74 @@ void KileProjectItem::allChildren(QPtrList<KileProjectItem> *list) const
 {
 	KileProjectItem *item = firstChild();
 
-// 	kdDebug() << "\tKileProjectItem::allChildren(" << list->count() << ")" << endl;
+// 	KILE_DEBUG() << "\tKileProjectItem::allChildren(" << list->count() << ")" << endl;
 	while(item != 0)
 	{
 		list->append(item);
-// 		kdDebug() << "\t\tappending " << item->url().fileName() << endl;
+// 		KILE_DEBUG() << "\t\tappending " << item->url().fileName() << endl;
 		item->allChildren(list);
 		item = item->sibling();
 	}
 }
 
-void KileProjectItem::setInfo(KileDocument::Info *docinfo)
+void KileProjectItem::setInfo(KileDocument::TextInfo *docinfo)
 {
 	m_docinfo = docinfo;
 	if(docinfo)
 	{
-	connect(docinfo,SIGNAL(nameChanged(const KURL &)), this, SLOT(changeURL(const KURL &)));
+	connect(docinfo,SIGNAL(urlChanged(KileDocument::Info*, const KURL &)), this, SLOT(slotChangeURL(KileDocument::Info*, const KURL &)));
 	connect(docinfo,SIGNAL(depChanged()), m_project, SLOT(buildProjectTree()));
 	}
 }
 
+void KileProjectItem::changeURL(const KURL &url)
+{
+	// don't allow empty URLs
+	if(!url.isEmpty() && m_url != url) 
+	{
+		m_url = url;
+		emit(urlChanged(this));
+	}
+}
+
+void KileProjectItem::slotChangeURL(KileDocument::Info*, const KURL &url)
+{
+	changeURL(url);
+}
+
 /*
  * KileProject
  */
-KileProject::KileProject(const QString& name, const KURL& url) : QObject(0,name.ascii()), m_invalid(false), m_masterDocument(QString::null), m_useMakeIndexOptions(false)
+KileProject::KileProject(const QString& name, const KURL& url, KileDocument::Extensions *extensions) : QObject(0,name.ascii()), m_invalid(false), m_masterDocument(QString::null), m_useMakeIndexOptions(false)
 {
-	init(name, url);
+	init(name, url, extensions);
 }
 
-KileProject::KileProject(const KURL& url) : QObject(0,url.fileName().ascii()), m_invalid(false), m_masterDocument(QString::null), m_useMakeIndexOptions(false)
+KileProject::KileProject(const KURL& url, KileDocument::Extensions *extensions) : QObject(0,url.fileName().ascii()), m_invalid(false), m_masterDocument(QString::null), m_useMakeIndexOptions(false)
 {
-	init(url.fileName(), url);
+	init(url.fileName(), url, extensions);
 }	
 
 KileProject::~KileProject()
 {
-	kdDebug() << "DELETING KILEPROJECT " <<  m_projecturl.url() << endl;
+	KILE_DEBUG() << "DELETING KILEPROJECT " <<  m_projecturl.url() << endl;
 	delete m_config;
 }
 
-void KileProject::init(const QString& name, const KURL& url)
+void KileProject::init(const QString& name, const KURL& url, KileDocument::Extensions *extensions)
 {
 	m_name = name;
-	m_projecturl = url;
+	m_projecturl = KileDocument::Manager::symlinkFreeURL( url);;
+
 	m_projectitems.setAutoDelete(true);
 
 	m_config = new KSimpleConfig(m_projecturl.path());
+	m_extmanager = extensions;
 
 	m_baseurl = m_projecturl.directory();
 	m_baseurl.cleanPath(true);
 
-	kdDebug() << "KileProject m_baseurl = " << m_baseurl.path() << endl;
+	KILE_DEBUG() << "KileProject m_baseurl = " << m_baseurl.path() << endl;
 
 	if (QFileInfo(url.path()).exists())
 	{
@@ -166,37 +201,77 @@ void KileProject::init(const QString& name, const KURL& url)
 void KileProject::setLastDocument(const KURL &url)
 {
     if ( item(url) != 0 )
-        m_lastDocument = url;
+        m_lastDocument = KileDocument::Manager::symlinkFreeURL(url);
 }
 
 void KileProject::setExtensions(KileProjectItem::Type type, const QString & ext)
 {
-	QString pattern = ext;
-
-	if (type < 1) 
+	if (type<KileProjectItem::Source || type>KileProjectItem::Image) 
 	{
-		kdWarning() << "ERROR: TYPE < 1" << endl;
+		kdWarning() << "ERROR: TYPE<1 or TYPE>3" << endl;
 		return;
 	}
 
-	if (ext.stripWhiteSpace().length() == 0) pattern = "";
+	// first we take all standard extensions
+	QStringList standardExtList;
+	if ( type == KileProjectItem::Source )
+		standardExtList = QStringList::split(" ", m_extmanager->latexDocuments() );
+	else if ( type == KileProjectItem::Package )
+		standardExtList = QStringList::split(" ", m_extmanager->latexPackages() );
+	else // if ( type == KileProjectItem::Image )
+		standardExtList = QStringList::split(" ", m_extmanager->images() );
 
-	if ( (!pattern.isEmpty()) && !extIsRegExp(type))
+	// now we scan user defined list and accept all extension, 
+	// except standard extensions of course
+	QString userExt;
+	if ( ! ext.isEmpty() )
 	{
-		QStringList lst = QStringList::split(" ", ext);
-		pattern = lst.join("|");
-		pattern.replace(".","\\.");
-		pattern ="("+ pattern +")$";
+		QStringList userExtList;
+
+		QStringList::ConstIterator it;
+		QStringList list = QStringList::split(" ", ext);
+		for ( it=list.begin(); it != list.end(); ++it ) 
+		{
+			// some tiny extension checks
+			if ( (*it).length()<2 || (*it)[0]!='.' )
+				continue;
+
+			// some of the old definitions are wrong, so we test them all
+			if ( type==KileProjectItem::Source || type==KileProjectItem::Package)
+			{
+				if ( ! (m_extmanager->isLatexDocument(*it) || m_extmanager->isLatexPackage(*it)) )
+				{
+					standardExtList << (*it);
+					userExtList << (*it);
+				}
+			}
+			else // if ( type == KileProjectItem::Image )
+			{
+				if ( ! m_extmanager->isImage(*it) )
+				{
+					standardExtList << (*it);
+					userExtList << (*it);
+				}
+			}
+		}
+		if ( userExtList.count() > 0 )
+			userExt = userExtList.join(" ");	
 	}
 
-	if ( extIsRegExp(type) )
-		pattern = ext.stripWhiteSpace();
+	// now we build a regular expression for all extensions
+	// (used to search for a filename with a valid extension)
+	QString pattern = standardExtList.join("|");
+	pattern.replace(".","\\.");
+	pattern = '('+ pattern +")$";
 
+	// and save it
 	m_reExtensions[type-1].setPattern(pattern);
 
-	if (m_extensions[type-1] != ext)
+	// if the list of user defined extensions has changed
+	// we save the new value and (re)build the project tree
+	if (m_extensions[type-1] != userExt)
 	{
-		m_extensions[type-1] = ext.stripWhiteSpace();
+		m_extensions[type-1] = userExt;
 		buildProjectTree();
 	}
 }
@@ -211,15 +286,17 @@ void KileProject::setType(KileProjectItem *item)
 
 	bool unknown = true;
 	for (int i = KileProjectItem::Source; i < KileProjectItem::Other; ++i)
-		if ( (!extensions((KileProjectItem::Type) i).isEmpty()) &&
-			m_reExtensions[i-1].search(item->url().fileName()) != -1)
+	{
+		if ( m_reExtensions[i-1].search(item->url().fileName()) != -1)
 		{
 			item->setType(i);
 			unknown = false;
 			break;
 		}
+	}
 
-	if (unknown) item->setType(KileProjectItem::Other);
+	if (unknown)
+		item->setType(KileProjectItem::Other);
 }
 
 void KileProject::readMakeIndexOptions()
@@ -252,15 +329,14 @@ void KileProject::writeUseMakeIndexOptions()
 
 QString KileProject::addBaseURL(const QString &path)
 {
-  if ( path.isEmpty() || path.startsWith("/") )
-  {
-    return path;
-  }
-  else
-  {
-    return m_baseurl.path() + "/" + path;
-  }
-}
+	KILE_DEBUG() << "===addBaseURL(const QString & " << path << " )" << endl;
+	if ( path.isEmpty())
+		return path;
+  	else if ( path.startsWith("/") )
+  		return KileDocument::Manager::symlinkFreeURL(KURL::fromPathOrURL(path)).path();
+  	else
+    		return  KileDocument::Manager::symlinkFreeURL(KURL::fromPathOrURL(m_baseurl.path() + '/' +path)).path();
+ }
 
 QString KileProject::removeBaseURL(const QString &path)
 {
@@ -269,7 +345,7 @@ QString KileProject::removeBaseURL(const QString &path)
   {
     QFileInfo info(path);
     QString relPath = findRelativePath(path);
-    kdDebug() << "removeBaseURL path is" << path << " , relPath is " << relPath << endl;
+    KILE_DEBUG() << "removeBaseURL path is" << path << " , relPath is " << relPath << endl;
     return relPath;
   }
   else
@@ -280,7 +356,7 @@ QString KileProject::removeBaseURL(const QString &path)
 
 bool KileProject::load()
 {
-	kdDebug() << "KileProject: loading..." <<endl;
+	KILE_DEBUG() << "KileProject: loading..." <<endl;
 
 	//load general settings/options
 	m_config->setGroup("General");
@@ -301,16 +377,12 @@ bool KileProject::load()
 	}
 	
 	QString master = addBaseURL(m_config->readEntry("masterDocument", QString::null));
-  	kdDebug() << "LOADED MASTER = " << master << endl;
+  	KILE_DEBUG() << "masterDoc == " << master << endl;
 	setMasterDocument(master);
 
-	// IsRegExp has to be loaded _before_ the Extensions
-	setExtIsRegExp(KileProjectItem::Source, m_config->readBoolEntry("src_extIsRegExp", false));
-	setExtensions(KileProjectItem::Source, m_config->readEntry("src_extensions", SOURCE_EXTENSIONS));
-	setExtIsRegExp(KileProjectItem::Package, m_config->readBoolEntry("pkg_extIsRegExp", false));
-	setExtensions(KileProjectItem::Package, m_config->readEntry("pkg_extensions", PACKAGE_EXTENSIONS));
-	setExtIsRegExp(KileProjectItem::Image, m_config->readBoolEntry("img_extIsRegExp", false));
-	setExtensions(KileProjectItem::Image, m_config->readEntry("img_extensions", IMAGE_EXTENSIONS));
+	setExtensions(KileProjectItem::Source, m_config->readEntry("src_extensions",m_extmanager->latexDocuments()));
+	setExtensions(KileProjectItem::Package, m_config->readEntry("pkg_extensions",m_extmanager->latexPackages()));
+	setExtensions(KileProjectItem::Image, m_config->readEntry("img_extensions",m_extmanager->images()));
 
 	setQuickBuildConfig(KileTool::configName("QuickBuild", m_config));
 
@@ -341,7 +413,7 @@ bool KileProject::load()
 				url.addPath(path);
 				url.cleanPath(true);
 			}
-			item = new KileProjectItem(this, url);
+			item = new KileProjectItem(this, KileDocument::Manager::symlinkFreeURL(url));
 			setType(item);
 
 			m_config->setGroup(groups[i]);
@@ -351,6 +423,7 @@ bool KileProject::load()
 			item->setArchive(m_config->readBoolEntry("archive", true));
 			item->setLineNumber(m_config->readNumEntry("line", 0));
 			item->setColumnNumber(m_config->readNumEntry("column", 0));
+			item->setOrder(m_config->readNumEntry("order", -1));
 			item->changePath(groups[i].mid(5));
 
 			connect(item, SIGNAL(urlChanged(KileProjectItem*)), this, SLOT(itemRenamed(KileProjectItem*)) );
@@ -361,30 +434,32 @@ bool KileProject::load()
     m_config->setGroup("General");
     setLastDocument(KURL::fromPathOrURL(addBaseURL(m_config->readEntry("lastDocument", QString::null))));
 
-	// dump();
+// 	dump();
 
 	return true;
 }
 
 bool KileProject::save()
 {
-	kdDebug() << "KileProject: saving..." <<endl;
+	KILE_DEBUG() << "KileProject: saving..." <<endl;
 
 	m_config->setGroup("General");
 	m_config->writeEntry("name", m_name);
 	m_config->writeEntry("kileprversion", kilePrVersion);
 	m_config->writeEntry("kileversion", kileVersion);
 
-  	kdDebug() << "KileProject::save() masterDoc = " << m_masterDocument << endl;
+  	KILE_DEBUG() << "KileProject::save() masterDoc = " << removeBaseURL(m_masterDocument) << endl;
 	m_config->writeEntry("masterDocument", removeBaseURL(m_masterDocument));
   	m_config->writeEntry("lastDocument", removeBaseURL(m_lastDocument.path()));
 
-	m_config->writeEntry("src_extensions", extensions(KileProjectItem::Source));
-	m_config->writeEntry("src_extIsRegExp", extIsRegExp(KileProjectItem::Source));
-	m_config->writeEntry("pkg_extensions", extensions(KileProjectItem::Package));
-	m_config->writeEntry("pkg_extIsRegExp", extIsRegExp(KileProjectItem::Package));
-	m_config->writeEntry("img_extensions", extensions(KileProjectItem::Image));
-	m_config->writeEntry("img_extIsRegExp", extIsRegExp(KileProjectItem::Image));
+
+	writeConfigEntry("src_extensions",m_extmanager->latexDocuments(),KileProjectItem::Source);
+	writeConfigEntry("pkg_extensions",m_extmanager->latexPackages(),KileProjectItem::Package);
+	writeConfigEntry("img_extensions",m_extmanager->images(),KileProjectItem::Image);
+	// only to avoid problems with older versions
+	m_config->writeEntry("src_extIsRegExp", false);
+	m_config->writeEntry("pkg_extIsRegExp", false);
+	m_config->writeEntry("img_extIsRegExp", false);
 
 	KileProjectItem *item;
 	for (uint i=0; i < m_projectitems.count(); ++i)
@@ -397,6 +472,7 @@ bool KileProject::save()
 		m_config->writeEntry("archive", item->archive());
 		m_config->writeEntry("line", item->lineNumber());
 		m_config->writeEntry("column", item->columnNumber());
+		m_config->writeEntry("order", item->order());
 	}
 
 	KileTool::setConfigName("QuickBuild", quickBuildConfig(), m_config);
@@ -418,13 +494,23 @@ bool KileProject::save()
 	return true;
 }
 
+void KileProject::writeConfigEntry(const QString &key, const QString &standardExt, KileProjectItem::Type type)
+{
+	QString userExt = extensions(type);
+	if ( userExt.isEmpty() )
+		m_config->writeEntry(key,standardExt);
+	else
+		m_config->writeEntry(key,standardExt + ' ' + extensions(type));
+}
+
 void KileProject::buildProjectTree()
 {
-	kdDebug() << "==KileProject::buildProjectTree==========================" << endl;
+	KILE_DEBUG() << "==KileProject::buildProjectTree==========================" << endl;
 
 	//determine the parent doc for each item (TODO:an item can only have one parent, not necessarily true for LaTeX docs)
 
 	const QStringList *deps;
+	QString dep;
 	KileProjectItem *itm;
 	KURL url;
 	QPtrListIterator<KileProjectItem> it(m_projectitems);
@@ -448,11 +534,16 @@ void KileProject::buildProjectTree()
 			deps = (*it)->getInfo()->dependencies();
 			for (uint i=0; i < deps->count(); ++i)
 			{
-				url = m_baseurl;
-				url.addPath((*deps)[i]);
-                url.cleanPath();
+				dep = (*deps)[i];
+
+				if( m_extmanager->isTexFile(dep) )
+					url = KileInfo::checkOtherPaths(m_baseurl,dep,KileInfo::texinputs);
+				else if( m_extmanager->isBibFile(dep) )
+					url = KileInfo::checkOtherPaths(m_baseurl,dep,KileInfo::bibinputs);
+				
 				itm = item(url);
-				if (itm && (itm->parent() == 0)) itm->setParent(*it);
+				if (itm && (itm->parent() == 0))
+					itm->setParent(*it);
 			}
 		}
 
@@ -484,9 +575,24 @@ KileProjectItem* KileProject::item(const KURL & url)
 	return 0;
 }
 
+KileProjectItem* KileProject::item(const KileDocument::Info *info)
+{
+	QPtrListIterator<KileProjectItem> it(m_projectitems);
+	KileProjectItem *current;
+	while ((current = it.current()) != 0)
+	{
+		++it;
+		if (current->getInfo() == info)
+		{
+			return current;
+		}
+	}
+	return 0;
+}
+
 void KileProject::add(KileProjectItem* item)
 {
-	kdDebug() << "KileProject::add projectitem" << item->url().path() << endl;
+	KILE_DEBUG() << "KileProject::add projectitem" << item->url().path() << endl;
 
 	setType(item);
 
@@ -505,7 +611,7 @@ void KileProject::remove(const KileProjectItem* item)
 	else
 		kdWarning() << "KileProject::remove() Failed to delete the group corresponding to this item!!!" <<endl;
 
-	kdDebug() << "KileProject::remove" << endl;
+	KILE_DEBUG() << "KileProject::remove" << endl;
 	m_projectitems.remove(item);
 
 	// dump();
@@ -513,8 +619,8 @@ void KileProject::remove(const KileProjectItem* item)
 
 void KileProject::itemRenamed(KileProjectItem *item)
 {
-	kdDebug() << "==KileProject::itemRenamed==========================" << endl;
-	kdDebug() << "\t" << item->url().fileName() << endl;
+	KILE_DEBUG() << "==KileProject::itemRenamed==========================" << endl;
+	KILE_DEBUG() << "\t" << item->url().fileName() << endl;
 	m_config->deleteGroup("item:"+item->path());
 	//config.sync();
 
@@ -527,8 +633,8 @@ QString KileProject::findRelativePath(const KURL &url)
 	QString path = url.directory();
 	QString filename = url.fileName();
 
- 	kdDebug() <<"===findRelativeURL==================" << endl;
- 	kdDebug() << "\tbasepath : " <<  basepath << " path: " << path << endl;
+ 	KILE_DEBUG() <<"===findRelativeURL==================" << endl;
+ 	KILE_DEBUG() << "\tbasepath : " <<  basepath << " path: " << path << endl;
 
 //   if ( basepath == path )
 //   {
@@ -543,12 +649,12 @@ QString KileProject::findRelativePath(const KURL &url)
 
 // 	for (uint i=0; i < basedirs.count(); ++i)
 // 	{
-// 		kdDebug() << "\t\tbasedirs " << i << ": " << basedirs[i] << endl;
+// 		KILE_DEBUG() << "\t\tbasedirs " << i << ": " << basedirs[i] << endl;
 // 	}
 
 // 	for (uint i=0; i < dirs.count(); ++i)
 // 	{
-//  		kdDebug() << "\t\tdirs " << i << ": " << dirs[i] << endl;
+//  		KILE_DEBUG() << "\t\tdirs " << i << ": " << dirs[i] << endl;
 // 	}
 
 	while ( dirs.count() > 0 && basedirs.count() > 0 &&  dirs[0] == basedirs[0] )
@@ -557,15 +663,15 @@ QString KileProject::findRelativePath(const KURL &url)
 		basedirs.pop_front();
 	}
 
-// 	kdDebug() << "\tafter" << endl;
+// 	KILE_DEBUG() << "\tafter" << endl;
 // 	for (uint i=0; i < basedirs.count(); ++i)
 // 	{
-// 		kdDebug() << "\t\tbasedirs " << i << ": " << basedirs[i] << endl;
+// 		KILE_DEBUG() << "\t\tbasedirs " << i << ": " << basedirs[i] << endl;
 // 	}
 // 
 // 	for (uint i=0; i < dirs.count(); ++i)
 // 	{
-// 		kdDebug() << "\t\tdirs " << i << ": " << dirs[i] << endl;
+// 		KILE_DEBUG() << "\t\tdirs " << i << ": " << dirs[i] << endl;
 // 	}
 
 	if (nDirs != dirs.count() )
@@ -580,7 +686,7 @@ QString KileProject::findRelativePath(const KURL &url)
 			}
 		}
 
-		if ( path.length()>0 && path.right(1) != "/" ) path = path + "/";
+		if ( path.length() > 0 && path.right(1) != "/" ) path = path + '/';
 
 		path = path+filename;
 	}
@@ -589,7 +695,7 @@ QString KileProject::findRelativePath(const KURL &url)
 		path = url.path();
 	}
 
-//  	kdDebug() << "\tpath : " << path << endl;
+//  	KILE_DEBUG() << "\tpath : " << path << endl;
 
 	return path;
 }
@@ -605,6 +711,21 @@ bool KileProject::contains(const KURL &url)
 	return false;
 }
 
+bool KileProject::contains(const KileDocument::Info *info)
+{
+	QPtrListIterator<KileProjectItem> it(m_projectitems);
+	KileProjectItem *current;
+	while( (current = it.current()) != 0)
+	{
+		++it;
+		if(current->getInfo() == info)
+		{
+			return true;
+		}
+	}
+	return false;
+}
+
 KileProjectItem *KileProject::rootItem(KileProjectItem *item) const
 {
 	//find the root item (i.e. the eldest parent)
@@ -639,9 +760,35 @@ KileProjectItem *KileProject::rootItem(KileProjectItem *item) const
 
 void KileProject::dump()
 {
-	kdDebug() << "KileProject::dump() " << m_name << endl;
+	KILE_DEBUG() << "KileProject::dump() " << m_name << endl;
 	for ( uint i=0; i < m_projectitems.count(); ++i)
-		kdDebug() << "\titem " << i << " : "  << m_projectitems.at(i)->path() << endl;
+	{
+		KileProjectItem *item;
+		item = m_projectitems.at(i);
+		KILE_DEBUG() << "item " << i << " has path: "  << item->path() << endl;
+		KILE_DEBUG() << "item->type() " << item->type() << endl;
+		KILE_DEBUG() << "OpenState: " << item->isOpen() << endl;
+	}
+}
+
+QString KileProject::archiveFileList() const
+{
+	KILE_DEBUG() << "KileProject::archiveFileList()" << endl;
+
+	QString path,list;
+	QPtrListIterator<KileProjectItem> it(m_projectitems);
+	
+	while (it.current())
+	{
+		if ((*it)->archive())
+		{
+			path = (*it)->path();
+			KRun::shellQuote(path);
+			list.append(path + ' ');
+		}
+		++it;
+	}
+	return list;
 }
 
 void KileProject::setMasterDocument(const QString & master){
@@ -653,7 +800,7 @@ void KileProject::setMasterDocument(const QString & master){
 			m_masterDocument = master;
 		else{
 			m_masterDocument = QString::null;
-			kdDebug() << "setMasterDocument: masterDoc=NULL" << endl;	
+			KILE_DEBUG() << "setMasterDocument: masterDoc=NULL" << endl;	
 		}
 	
 	}
