@@ -1,8 +1,10 @@
-/***************************************************************************
+/**************************************************************************************
     begin                : Fri 18-06-2004
-    copyright            : (C) 2004 by Jeroen Wijnhout
-    email                :  Jeroen.Wijnhout@kdemail.net
- ***************************************************************************/
+    edit 		 : Wed 1 Jun 2006
+    copyright            : (C) 2004 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
+                           (C) 2006 by Thomas Braun (braun@physik.fu-berlin.de)
+                           (C) 2006 by Michel Ludwig (michel.ludwig@kdemail.net)
+ **************************************************************************************/
 
 /***************************************************************************
  *                                                                         *
@@ -12,20 +14,20 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- 
+
+#include "kilesidebar.h"
+
 #include <qwidgetstack.h>
 #include <qlayout.h>
 
 #include <kdeversion.h>
-#include <kdebug.h>
-#include <kmultitabbar.h>
+#include "kiledebug.h"
+#include <kilemultitabbar.h>
 
 #include "symbolview.h"
-#include "kilesidebar.h"
 
-KileSideBar::KileSideBar(int size, QWidget *parent, const char *name, Qt::Orientation orientation /*= Vertical*/, bool alwaysShowLabels /*= false*/) : 
+KileSideBar::KileSideBar(int size, QWidget *parent, const char *name, Qt::Orientation orientation /*= Vertical*/) : 
 	QFrame(parent, name),
-	m_symbolTab(0L),
 	m_nTabs(0),
 	m_nCurrent(0),
 	m_bMinimized(false),
@@ -33,8 +35,7 @@ KileSideBar::KileSideBar(int size, QWidget *parent, const char *name, Qt::Orient
 	m_nMaxSize(1000),
 	m_nSize(size)
 {
-	setFrameStyle(QFrame::Box|QFrame::Plain);
-	setLineWidth(1);
+	setLineWidth(0);
 	setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
  
 	QLayout *layout;
@@ -42,29 +43,29 @@ KileSideBar::KileSideBar(int size, QWidget *parent, const char *name, Qt::Orient
 	m_tabStack = new QWidgetStack(this);
 	m_tabStack->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
 
-	KMultiTabBar::KMultiTabBarMode tabbarori = KMultiTabBar::Horizontal;
-	KMultiTabBar::KMultiTabBarPosition tabbarpos = KMultiTabBar::Top;
+	KileMultiTabBar::KileMultiTabBarMode tabbarori = KileMultiTabBar::Horizontal;
+	KileMultiTabBar::KileMultiTabBarPosition tabbarpos = KileMultiTabBar::Top;
 	if ( orientation == Qt::Horizontal ) 
 	{
 		layout = new QVBoxLayout(this);
-		tabbarori = KMultiTabBar::Horizontal;
-		tabbarpos = KMultiTabBar::Top;
+		tabbarori = KileMultiTabBar::Horizontal;
+		tabbarpos = KileMultiTabBar::Top;
 	}
 	else if ( orientation == Qt::Vertical ) 
 	{
 		layout = new QHBoxLayout(this);
-		tabbarori = KMultiTabBar::Vertical;
-		tabbarpos = KMultiTabBar::Right;
+		tabbarori = KileMultiTabBar::Vertical;
+		tabbarpos = KileMultiTabBar::Right;
 	}
 
-	m_tabBar = new KMultiTabBar(tabbarori, this);
+	m_tabBar = new KileMultiTabBar(tabbarori, this);
 	m_tabBar->setPosition(tabbarpos);
+
 	#if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
-		m_tabBar->setStyle(alwaysShowLabels ? KMultiTabBar::KDEV3ICON : KMultiTabBar::VSNET);
-	#else
-		m_tabBar->setStyle(alwaysShowLabels ? KMultiTabBar::KDEV3 : KMultiTabBar::VSNET);
-	#endif
-	
+		m_tabBar->setStyle(KileMultiTabBar::KDEV3ICON);
+ 	#else
+ 		m_tabBar->setStyle(KileMultiTabBar::KDEV3);
+ 	#endif
 
 	if ( orientation == Qt::Horizontal )
 	{
@@ -76,10 +77,6 @@ KileSideBar::KileSideBar(int size, QWidget *parent, const char *name, Qt::Orient
 	}
 	else if ( orientation == Qt::Vertical )
 	{
-		m_symbolTab = new SymbolView(m_tabStack);
-		m_tabStack->addWidget(m_symbolTab, 0);
-		++m_nTabs;
-
 		setMinimumWidth(m_tabBar->width());
 		m_nMinSize = m_tabBar->width();
 		m_nMaxSize = m_tabBar->maximumWidth();
@@ -94,7 +91,6 @@ KileSideBar::~KileSideBar()
 
 int KileSideBar::addTab(QWidget *tab, const QPixmap &pic, const QString &text /* = QString::null*/)
 {
-	m_isSymbolView[m_nTabs] = false;
 	m_widgetToIndex[tab] = m_nTabs;
 
 	m_tabBar->appendTab(pic, m_nTabs, text);
@@ -104,21 +100,10 @@ int KileSideBar::addTab(QWidget *tab, const QPixmap &pic, const QString &text /*
 	return m_nTabs++;
 }
 
-int KileSideBar::addSymbolTab(int page, const QPixmap &pic, const QString &text /* = QString::null*/)
-{
-	m_widgetToIndex[m_symbolTab] = m_nTabs;
-	m_isSymbolView[m_nTabs] = true;
-	m_indexToPage[m_nTabs] = page;
-
-	m_tabBar->appendTab(pic, m_nTabs, text);
-	connect(m_tabBar->tab(m_nTabs), SIGNAL(clicked(int)), this, SLOT(showTab(int)));
-
-	return m_nTabs++;
-}
 
 void KileSideBar::setVisible(bool show)
 {
-	kdDebug() << "==KileSideBar::setVisible(" << show << ")===========" << endl;
+	KILE_DEBUG() << "==KileSideBar::setVisible(" << show << ")===========" << endl;
 	if (show) expand();
 	else shrink();
 }
@@ -159,6 +144,60 @@ QWidget* KileSideBar::currentPage()
 	return m_tabStack->visibleWidget();
 }
 
+int KileSideBar::findNextShownTab(int i)
+{
+	if(m_nTabs <= 0)
+	{
+		return -1;
+	}
+	for(int j = 1; j < m_nTabs; ++j)
+	{
+		int index = (i + j) % m_nTabs;
+		if(m_tabBar->tab(index)->isShown())
+		{
+			return index;
+		}
+	}
+	return -1;
+}
+
+void KileSideBar::removePage(QWidget *w) 
+{
+	QMap<QWidget*,int>::iterator it = m_widgetToIndex.find(w);
+	if(it == m_widgetToIndex.end())
+	{
+		return;
+	}
+	int index = *it;
+	m_tabStack->removeWidget(w);
+	disconnect(m_tabBar->tab(index), SIGNAL(clicked(int)), this, SLOT(showTab(int)));
+	m_tabBar->removeTab(index);
+	m_widgetToIndex.remove(it);
+	if(index == m_nCurrent && m_nTabs >= 2)
+	{
+		showTab(findNextShownTab(index));
+	}
+	--m_nTabs;
+}
+
+void KileSideBar::setPageVisible(QWidget *w, bool b) {
+	QMap<QWidget*,int>::iterator it = m_widgetToIndex.find(w);
+	if(it == m_widgetToIndex.end())
+	{
+		return;
+	}
+	int index = *it;
+	KileMultiTabBarTab *tab = m_tabBar->tab(index);
+	if(tab->isShown() == b) {
+		return;
+	}
+  	tab->setShown(b);
+	if(!b && index == m_nCurrent && m_nTabs >= 2)
+	{
+		showTab(findNextShownTab(index));
+	}
+}
+
 void KileSideBar::showPage(QWidget *widget)
 {
 	if ( m_widgetToIndex.contains(widget) )
@@ -167,6 +206,10 @@ void KileSideBar::showPage(QWidget *widget)
 
 void KileSideBar::showTab(int id)
 {
+	if(id >= m_nTabs || id < 0)
+	{
+		return;
+	}
 	if ( id != m_nCurrent)
 	{
 		switchToTab(id);
@@ -184,19 +227,19 @@ void KileSideBar::toggleTab()
 
 void KileSideBar::switchToTab(int id)
 {
+	if(id >= m_nTabs || id < 0) {
+		return;
+	}
 	m_tabBar->setTab(m_nCurrent, false);
 	m_tabBar->setTab(id, true);
 
-	int tabId = isSymbolView(id) ? 0 : id;
-	if ( isSymbolView(id) ) m_symbolTab->showPage(m_indexToPage[id]);
-
-	m_tabStack->raiseWidget(tabId);
+	m_tabStack->raiseWidget(id);
 
 	m_nCurrent = id;
 }
 
 KileBottomBar::KileBottomBar(int size, QWidget *parent, const char *name) :
-	KileSideBar(size, parent, name, Qt::Horizontal, true)
+	KileSideBar(size, parent, name, Qt::Horizontal)
 {}
 
 void KileBottomBar::shrink()
