@@ -5,6 +5,7 @@
 //
 //
 // Author: Jeroen Wijnhout <Jeroen.Wijnhout@kdemail.net>, (C) 2004
+//         Michel Ludwig <michel.ludwig@kdemail.net>, (C) 2006, 2007
 
 /***************************************************************************
  *                                                                         *
@@ -15,6 +16,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "kileviewmanager.h"
+
 #include <qpopupmenu.h>
 #include <qtimer.h> //for QTimer::singleShot trick
 #include <qpixmap.h>
@@ -32,15 +35,20 @@
 #include <klocale.h>
 #include <ktexteditor/editinterfaceext.h>
 #include <kapplication.h>
+#include <kurldrag.h>
 
+#include "editorkeysequencemanager.h"
 #include "kileinfo.h"
+#include "kileconstants.h"
 #include "kiledocmanager.h"
-#include "kileviewmanager.h"
+#include "kileextensions.h"
 #include "kileprojectview.h"
 #include "kileeventfilter.h"
 #include "kilestructurewidget.h"
 #include "kileedit.h"
 #include "plaintolatexconverter.h"
+#include "previewwidget.h"
+#include "quickpreview.h"
 
 namespace KileView 
 {
@@ -48,9 +56,11 @@ namespace KileView
 Manager::Manager(KileInfo *info, QObject *parent, const char *name) :
 	QObject(parent, name),
 	m_ki(info),
-	m_activeView(0L),
-	m_projectview(0L),
-	m_tabs(0L)
+	m_activeTextView(0L),
+// 	m_projectview(0L),
+	m_tabs(0L),
+	m_widgetStack(0L),
+	m_emptyDropWidget(0L)
 {
 }
 
@@ -70,13 +80,19 @@ void Manager::setClient(QObject *receiver, KXMLGUIClient *client)
 		new KAction(i18n("Convert Selection to &LaTeX"), 0, this,
 			SLOT(convertSelectionToLaTeX()), m_client->actionCollection(), "popup_converttolatex");
 	if(NULL == m_client->actionCollection()->action("popup_quickpreview"))
-		new KAction(i18n("&QuickPreview Selection"), 0, receiver,
-			SLOT(quickPreviewSelection()), m_client->actionCollection(), "popup_quickpreview");
+		new KAction(i18n("&QuickPreview Selection"), 0, this,
+			SLOT(quickPreviewPopup()), m_client->actionCollection(), "popup_quickpreview");
 }
 
 void Manager::createTabs(QWidget *parent)
 {
+	m_widgetStack = new QWidgetStack(parent);
+	m_emptyDropWidget = new DropWidget(parent);
+	m_widgetStack->addWidget(m_emptyDropWidget);
+	connect(m_emptyDropWidget, SIGNAL(testCanDecode(const QDragMoveEvent *,  bool &)), this, SLOT(testCanDecodeURLs(const QDragMoveEvent *, bool &)));
+	connect(m_emptyDropWidget, SIGNAL(receivedDropEvent(QDropEvent *)), m_ki->docManager(), SLOT(openDroppedURLs(QDropEvent *)));
 	m_tabs = new KTabWidget(parent);
+	m_widgetStack->addWidget(m_tabs);
 	m_tabs->setFocusPolicy(QWidget::ClickFocus);
 	m_tabs->setTabReorderingEnabled(true);
 	m_tabs->setHoverCloseButton(true);
@@ -86,6 +102,10 @@ void Manager::createTabs(QWidget *parent)
 	connect( m_tabs, SIGNAL( currentChanged( QWidget * ) ), m_receiver, SLOT(activateView( QWidget * )) );
 	connect( m_tabs, SIGNAL( currentChanged( QWidget * ) ), m_receiver, SLOT(updateModeStatus()) );
 	connect( m_tabs, SIGNAL( closeRequest(QWidget *) ), this, SLOT(closeWidget(QWidget *)));
+	connect( m_tabs, SIGNAL( testCanDecode( const QDragMoveEvent *,  bool & ) ), this, SLOT(testCanDecodeURLs( const QDragMoveEvent *, bool & )) );
+	connect( m_tabs, SIGNAL( receivedDropEvent( QDropEvent * ) ), m_ki->docManager(), SLOT(openDroppedURLs( QDropEvent * )) );
+	connect( m_tabs, SIGNAL( receivedDropEvent( QWidget*, QDropEvent * ) ), this, SLOT(replaceLoadedURL( QWidget *, QDropEvent * )) );
+	m_widgetStack->raiseWidget(m_emptyDropWidget); // there are no tabs, so show the DropWidget
 }
 
 void Manager::closeWidget(QWidget *widget)
@@ -97,40 +117,45 @@ void Manager::closeWidget(QWidget *widget)
 	}
 }
 
-Kate::View* Manager::createView(Kate::Document *doc)
+Kate::View* Manager::createTextView(KileDocument::TextInfo *info, int index)
 {
-	Kate::View *view = (Kate::View*) doc->createView (m_tabs, 0L);
+	Kate::Document *doc = info->getDoc();
+	Kate::View *view = static_cast<Kate::View*>(info->createView (m_tabs, 0L));
 
-	//install event filter on the view
-	view->focusProxy()->installEventFilter(m_ki->eventFilter());
+	//install a key sequence recorder on the view
+	view->focusProxy()->installEventFilter(new KileEditorKeySequence::Recorder(view, m_ki->editorKeySequenceManager()));
+
+	// in the case of simple text documents, we mimic the behaviour of LaTeX documents
+	if(info->getType() == KileDocument::Text)
+	{
+		view->focusProxy()->installEventFilter(m_ki->eventFilter());
+	}
 
 	//insert the view in the tab widget
-	m_tabs->addTab( view, m_ki->getShortName(doc) );
-	m_tabs->setTabToolTip(view, doc->url().url() );
+	m_tabs->insertTab( view, m_ki->getShortName(doc), index );
+	#if KDE_VERSION >= KDE_MAKE_VERSION(3,4,0)
+		m_tabs->setTabToolTip(view, doc->url().pathOrURL() );
+	#else
+		m_tabs->setTabToolTip(view, doc->url().prettyURL() );
+	#endif
+	
 	m_tabs->showPage( view );
-	m_viewList.append(view);
+	m_textViewList.insert((index < 0 || (uint)index >= m_textViewList.count()) ? m_textViewList.count() : index, view);
 
 	connect(view, SIGNAL(viewStatusMsg(const QString&)), m_receiver, SLOT(newStatus(const QString&)));
 	connect(view, SIGNAL(newStatus()), m_receiver, SLOT(newCaption()));
+	connect(view, SIGNAL(dropEventPass(QDropEvent *)), m_ki->docManager(), SLOT(openDroppedURLs(QDropEvent *)));
+	connect(info, SIGNAL(urlChanged(KileDocument::Info*, const KURL&)), this, SLOT(urlChanged(KileDocument::Info*, const KURL&)));
 
 	connect( doc,  SIGNAL(charactersInteractivelyInserted (int,int,const QString&)), m_ki->editorExtension()->complete(),  SLOT(slotCharactersInserted(int,int,const QString&)) );
 	connect( view, SIGNAL(completionDone(KTextEditor::CompletionEntry)), m_ki->editorExtension()->complete(),  SLOT( slotCompletionDone(KTextEditor::CompletionEntry)) );
 	connect( view, SIGNAL(completionAborted()), m_ki->editorExtension()->complete(),  SLOT( slotCompletionAborted()) );
 	connect( view, SIGNAL(filterInsertString(KTextEditor::CompletionEntry*,QString *)), m_ki->editorExtension()->complete(),  SLOT(slotFilterCompletion(KTextEditor::CompletionEntry*,QString *)) );
 
-	KAction *spa = view->actionCollection()->action( "tools_spelling" );
-	if ( spa )
-	{
-		kdDebug() << "RECONNECTING SPELLCHECKER" << endl;
-		disconnect(spa , 0 , 0 , 0);
-		connect( spa, SIGNAL(activated()), this, SIGNAL(startSpellCheck()) );
-	}
-
 	// install a working kate part popup dialog thingy
-	Kate::View *kateView = static_cast<Kate::View*>(view->qt_cast("Kate::View"));
 	QPopupMenu *viewPopupMenu = (QPopupMenu*)(m_client->factory()->container("ktexteditor_popup", m_client));
-	if((NULL != kateView) && (NULL != viewPopupMenu))
-		kateView->installPopup(viewPopupMenu);
+	if((NULL != view) && (NULL != viewPopupMenu))
+		view->installPopup(viewPopupMenu);
 	if(NULL != viewPopupMenu)
 		connect(viewPopupMenu, SIGNAL(aboutToShow()), this, SLOT(onKatePopupMenuRequest()));
 
@@ -144,15 +169,24 @@ Kate::View* Manager::createView(Kate::Document *doc)
 	view->setFocus();
 
 	emit(prepareForPart("Editor"));
+	unplugKatePartMenu(view);
 
-	// remove 'configure editor' dialog of Kate
-	// this will be called directly from Kile
-	KAction *action = view->actionCollection()->action("set_confdlg"); 
+	// use Kile's save and save-as functions instead of Katepart's
+	KAction *action = view->actionCollection()->action(KStdAction::stdName(KStdAction::Save)); 
 	if ( action ) 
 	{
-		kdDebug() << "   unplug action 'set_confdlg'..." << endl;
-		action->unplugAll();
+		KILE_DEBUG() << "   reconnect action 'file_save'..." << endl;
+		action->disconnect(SIGNAL(activated()));
+		connect(action, SIGNAL(activated()), m_ki->docManager(), SLOT(fileSave()));
 	}
+	action = view->actionCollection()->action(KStdAction::stdName(KStdAction::SaveAs));
+	if ( action ) 
+	{
+		KILE_DEBUG() << "   reconnect action 'file_save_as'..." << endl;
+		action->disconnect(SIGNAL(activated()));
+		connect(action, SIGNAL(activated()), m_ki->docManager(), SLOT(fileSaveAs()));
+	}
+	m_widgetStack->raiseWidget(m_tabs); // there is at least one tab, so show the KTabWidget now
 
 	return view;
 }
@@ -164,20 +198,19 @@ void Manager::removeView(Kate::View *view)
 		m_client->factory()->removeClient(view);
 
 		m_tabs->removePage(view);
-		m_viewList.remove(view);
+		m_textViewList.remove(view);
 		delete view;
 		
 		QTimer::singleShot(0, m_receiver, SLOT(newCaption())); //make sure the caption gets updated
-		if (views().isEmpty()) m_ki->structureWidget()->clear();
+		if (textViews().isEmpty()) {
+			m_ki->structureWidget()->clear();
+			m_widgetStack->raiseWidget(m_emptyDropWidget); // there are no tabs left, so show
+			                                               // the DropWidget
+		}
 	}
 }
 
-void Manager::removeFromProjectView(const KURL & url)
-{
-	m_projectview->remove(url);
-}
-
-Kate::View *Manager::currentView() const
+Kate::View *Manager::currentTextView() const
 {
 	if ( m_tabs->currentPage() &&
 		m_tabs->currentPage()->inherits( "Kate::View" ) )
@@ -188,7 +221,33 @@ Kate::View *Manager::currentView() const
 	return 0;
 }
 
-Kate::View* Manager::switchToView(const KURL & url)
+Kate::View* Manager::textView(KileDocument::TextInfo *info)
+{
+	Kate::Document *doc = info->getDoc();
+	if(!doc)
+	{
+		return NULL;
+	}
+	for(Kate::View *view = m_textViewList.first(); view; view = m_textViewList.next())
+	{
+		if(view->getDoc() == doc)
+		{
+			return view;
+		}
+	}
+	return NULL;
+}
+
+int Manager::getIndexOf(Kate::View* view) const
+{
+	return m_tabs->indexOf(view);
+}
+
+unsigned int Manager::getTabCount() const {
+	return m_tabs->count();
+}
+
+Kate::View* Manager::switchToTextView(const KURL & url, bool requestFocus)
 {
 	Kate::View *view = 0L;
 	Kate::Document *doc = m_ki->docManager()->docFor(url);
@@ -196,9 +255,13 @@ Kate::View* Manager::switchToView(const KURL & url)
 	if (doc)
 	{
 		view = static_cast<Kate::View*>(doc->views().first());
-		m_tabs->showPage(view);
+		if(view)
+		{
+			m_tabs->showPage(view);
+			if(requestFocus)
+				view->setFocus();
+		}
 	}
-
 	return view;
 }
 
@@ -210,10 +273,10 @@ void Manager::updateStructure(bool parse /* = false */, KileDocument::Info *doci
 	if (docinfo)
 		m_ki->structureWidget()->update(docinfo, parse);
 
-	Kate::View *view = currentView();
+	Kate::View *view = currentTextView();
 	if (view) {view->setFocus();}
 
-	if ( views().count() == 0 )
+	if ( textViews().count() == 0 )
 		m_ki->structureWidget()->clear();
 }
 
@@ -250,9 +313,11 @@ void Manager::reflectDocumentStatus(Kate::Document *doc, bool isModified, unsign
 		icon = SmallIcon("revert");
 	else if ( reason == 3 ) //file deleted
 		icon = SmallIcon("stop");
+	else if ( m_ki->extensions()->isScriptFile(doc->url()) )
+		icon = SmallIcon("js");
 	else
 		icon = KMimeType::pixmapForURL (doc->url(), 0, KIcon::Small);
-	
+
 	changeTab(doc->views().first(), icon, m_ki->getShortName(doc));
 }
 
@@ -261,7 +326,7 @@ void Manager::reflectDocumentStatus(Kate::Document *doc, bool isModified, unsign
  */
 void Manager::onKatePopupMenuRequest(void)
 {
-	Kate::View *view = currentView();
+	Kate::View *view = currentTextView();
 	if(NULL == view)
 		return;
 
@@ -275,7 +340,10 @@ void Manager::onKatePopupMenuRequest(void)
 		if(!quickPreviewAction->isPlugged())
 			quickPreviewAction->plug(viewPopupMenu);
 
-		quickPreviewAction->setEnabled(view->getDoc()->hasSelection());
+		quickPreviewAction->setEnabled( view->getDoc()->hasSelection() || 
+		                                m_ki->editorExtension()->hasMathgroup(view) ||
+		                                m_ki->editorExtension()->hasEnvironment(view)
+		                              );
 	}
 
 	// Setting up the "Convert to LaTeX" entry
@@ -301,7 +369,7 @@ void Manager::onKatePopupMenuRequest(void)
 
 void Manager::convertSelectionToLaTeX(void)
 {
-	Kate::View *view = currentView();
+	Kate::View *view = currentTextView();
 
 	if(NULL == view)
 		return;
@@ -367,7 +435,7 @@ void Manager::convertSelectionToLaTeX(void)
  */
 void Manager::pasteAsLaTeX(void)
 {
-	Kate::View *view = currentView();
+	Kate::View *view = currentTextView();
 
 	if(NULL == view)
 		return;
@@ -404,6 +472,113 @@ void Manager::pasteAsLaTeX(void)
 		editInterfaceExt->editEnd();
 }
 
+void Manager::quickPreviewPopup()
+{
+	Kate::View *view = currentTextView();
+	if( ! view )
+		return;
+
+	Kate::Document *doc = view->getDoc();
+	if ( doc )
+	{
+		if ( doc->hasSelection() )
+			emit( startQuickPreview(KileTool::qpSelection) );
+		else if ( m_ki->editorExtension()->hasMathgroup(view) )
+			emit( startQuickPreview(KileTool::qpMathgroup) );
+		else if ( m_ki->editorExtension()->hasEnvironment(view) )
+			emit( startQuickPreview(KileTool::qpEnvironment) );
+	}
+}
+
+void Manager::testCanDecodeURLs(const QDragMoveEvent *e, bool &accept)
+{
+	accept = KURLDrag::canDecode(e); // only accept URL drops
+}
+
+void Manager::replaceLoadedURL(QWidget *w, QDropEvent *e)
+{
+	KURL::List urls;
+	if(!KURLDrag::decode(e, urls)) {
+		return;
+	}
+	int index = m_tabs->indexOf(w);
+	KileDocument::Extensions *extensions = m_ki->extensions();
+	bool hasReplacedTab = false;
+	for(KURL::List::iterator i = urls.begin(); i != urls.end(); ++i) {
+		KURL url = *i;
+		if(extensions->isProjectFile(url)) {
+			m_ki->docManager()->projectOpen(url);
+		}
+		else if(!hasReplacedTab) {
+			closeWidget(w);
+			m_ki->docManager()->fileOpen(url, QString::null, index);
+			hasReplacedTab = true;
+		}
+		else {
+			m_ki->docManager()->fileOpen(url);
+		}
+	}
+}
+
+void Manager::urlChanged(KileDocument::Info* info, const KURL& /*url*/)
+{
+	KileDocument::TextInfo *textInfo = dynamic_cast<KileDocument::TextInfo*>(info);
+	if(textInfo)
+	{
+		Kate::View *view = textView(textInfo);
+		if(!view)
+		{
+			return;
+		}
+		setTabLabel(view, m_ki->getShortName(textInfo->getDoc()));
+	}
+}
+
+DropWidget::DropWidget(QWidget * parent, const char * name, WFlags f) : QWidget(parent, name, f)
+{
+	setAcceptDrops(true);
+}
+
+DropWidget::~DropWidget()
+{
+}
+
+void DropWidget::dragMoveEvent(QDragMoveEvent *e)
+{
+	bool b;
+	emit testCanDecode(e, b);
+	e->accept(b);
+}
+
+void DropWidget::dropEvent(QDropEvent *e)
+{
+	emit receivedDropEvent(e);
+}
+
+// remove entries from KatePart menu: 
+//  - menu entry to config Kate, because there is
+//    already one call to this configuration dialog from Kile
+//  - goto line, because we put it into a submenu
+
+void Manager::unplugKatePartMenu(Kate::View* view)
+{
+	if ( view ) 
+	{
+		QStringList actionlist;
+		actionlist << "set_confdlg" << "go_goto_line";      // action names from katepartui.rc
+
+		for ( uint i=0; i < actionlist.count(); ++i )
+		{
+			KAction *action = view->actionCollection()->action( actionlist[i].ascii() ); 
+			if ( action ) 
+			{
+				action->unplugAll();
+//				action->setShortcut(KShortcut());
+			}
+		}
+	}
+}
+
 }
 
 #include "kileviewmanager.moc"
