@@ -1,10 +1,10 @@
 /***************************************************************************
                          texdocdialog.cpp
                          ----------------
-    date                 : Jan 22 2006
-    version              : 0.13
-    copyright            : (C) 2005-2006 by Holger Danielsson
-    email                : holger.danielsson@t-online.de
+    date                 : Feb 15 2007
+    version              : 0.14
+    copyright            : (C) 2005-2007 by Holger Danielsson
+    email                : holger.danielsson@versanet.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -35,7 +35,7 @@
 #include <kiconloader.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <kdebug.h>
+#include "kiledebug.h"
 #include <kdeversion.h>
 
 #include <ktrader.h>
@@ -88,7 +88,7 @@ TexDocDialog::TexDocDialog(QWidget *parent, const char *name)
 	vbox->addWidget(m_texdocs);
 	vbox->addWidget(groupbox);
 	
-	QWhatsThis::add(m_texdocs,i18n("A list of avaiblable documents, which are listed in 'texdoctk.dat', coming with teTeX. A double click with the mouse or pressing the space key will open a viewer to show this file."));
+	QWhatsThis::add(m_texdocs,i18n("A list of avaiblable documents, which are listed in 'texdoctk.dat', coming with TexLive/teTeX. A double click with the mouse or pressing the space key will open a viewer to show this file."));
 	QWhatsThis::add(m_leKeywords,i18n("You can choose a keyword to show only document files, which are related to this keyword."));
 	QWhatsThis::add(m_pbSearch,i18n("Start the search for the chosen keyword."));
 	QWhatsThis::add(actionButton(Help),i18n("Reset TOC to show all available files."));
@@ -188,11 +188,11 @@ void TexDocDialog::readToc()
 				basename = fi.baseName().lower();
 			}  
 			
-			QString entry = list[0] + ";" + list[1];
+			QString entry = list[0] + ';' + list[1];
 			if ( ! basename.isEmpty() )  
-				entry += ";" + basename;
+				entry += ';' + basename;
 			if ( list.count() > 3 )
-				entry += ";" + list[3];
+				entry += ';' + list[3];
 			m_tocSearchList.append(entry);
 		}
 	}
@@ -290,9 +290,9 @@ QString TexDocDialog::searchFile(const QString &docfilename,const QString &listo
 	{
 		for ( QStringList::Iterator ite = extlist.begin(); ite!=extlist.end(); ++ite ) 
 		{
-			filename = ( subdir.isEmpty() ) ? (*itp) + "/" + docfilename + (*ite)
-			                                : (*itp) + "/" + subdir + "/" + docfilename + (*ite);
-		 	// kdDebug() << "search file: "  << filename << endl;
+			filename = ( subdir.isEmpty() ) ? (*itp) + '/' + docfilename + (*ite)
+			                                : (*itp) + '/' + subdir + '/' + docfilename + (*ite);
+		 	// KILE_DEBUG() << "search file: "  << filename << endl;
 			if (  QFile::exists(filename) )
 				return filename;
 		}
@@ -310,18 +310,18 @@ void TexDocDialog::decompressFile(const QString &docfile,const QString &command)
 	if ( m_tempfile )
 		delete m_tempfile;
 		
-	m_tempfile = new KTempFile(QString::null,"."+ext);
+	m_tempfile = new KTempFile(QString::null, '.' + ext);
 	m_tempfile->setAutoDelete(true);
 	m_filename = m_tempfile->name();
 	
-	kdDebug() << "\tdecompress file: "  << command + " > " + m_tempfile->name() << endl;
+	KILE_DEBUG() << "\tdecompress file: "  << command + " > " + m_tempfile->name() << endl;
 	connect(this, SIGNAL(processFinished()), this, SLOT(slotShowFile()));
 	executeScript(command + " > " + m_tempfile->name());
 }
 
 void TexDocDialog::showStyleFile(const QString &filename,const QString &stylecode)
 {
-	kdDebug() << "\tshow style file: "<< filename << endl;
+	KILE_DEBUG() << "\tshow style file: "<< filename << endl;
 	if ( ! QFile::exists(filename) ) 
 		return;
 		
@@ -407,7 +407,7 @@ void TexDocDialog::showStyleFile(const QString &filename,const QString &stylecod
 
 void TexDocDialog::showFile(const QString &filename)
 {
-	kdDebug() << "\tshow file: "<< filename << endl;
+	KILE_DEBUG() << "\tshow file: "<< filename << endl;
 	if ( QFile::exists(filename) ) 
 	{
 		KURL url;
@@ -435,13 +435,13 @@ void TexDocDialog::slotListViewDoubleClicked(QListViewItem *item,const QPoint &,
 		return;
 		
 	QString package = item->text(1);
-	kdDebug() << "\tselect child: "  << item->text(0) << endl 
+	KILE_DEBUG() << "\tselect child: "  << item->text(0) << endl 
 	          << "\tis package: " << package << endl;
 	if ( ! m_dictDocuments.contains( package ) ) 
 		return;
 		
 	QString texdocfile = m_dictDocuments[package];
-	kdDebug() << "\tis texdocfile: " << texdocfile << endl;
+	KILE_DEBUG() << "\tis texdocfile: " << texdocfile << endl;
 	
 	// search for the file in the documentation directories
 	QString filename = searchFile(texdocfile,m_texmfdocPath);
@@ -455,7 +455,7 @@ void TexDocDialog::slotListViewDoubleClicked(QListViewItem *item,const QPoint &,
 			return;
 		}
 	}
-	kdDebug() << "\tfound file: " << filename << endl;
+	KILE_DEBUG() << "\tfound file: " << filename << endl;
 	
 	QString ext = QFileInfo(filename).extension(false).lower(); 
 	m_filename = QString::null;
@@ -544,10 +544,10 @@ void TexDocDialog::executeScript(const QString &command)
 	connect(m_proc, SIGNAL(processExited(KProcess*)),
 	        this,   SLOT(slotProcessExited(KProcess*)) );
 	  
-	kdDebug() << "=== TexDocDialog::runShellSkript() ====================" << endl;
-	kdDebug() << "   execute: " << command << endl;
+	KILE_DEBUG() << "=== TexDocDialog::runShellSkript() ====================" << endl;
+	KILE_DEBUG() << "   execute: " << command << endl;
 	if ( ! m_proc->start(KProcess::NotifyOnExit, KProcess::AllOutput) ) 
-		kdDebug() << "\tstart of shell process failed" << endl;
+		KILE_DEBUG() << "\tstart of shell process failed" << endl;
 }
 
 void TexDocDialog::slotProcessOutput(KProcess*,char* buf,int len)
@@ -565,7 +565,7 @@ void TexDocDialog::slotProcessExited(KProcess *proc)
 	} 
 	else 
 	{
-		KMessageBox::error( this,i18n("<center>") + i18n("Could not determine the search paths of teTeX or file 'texdoctk.dat'.<br> So this dialog is useless.") + i18n("</center>"),i18n("TexDoc Dialog") );
+		KMessageBox::error( this,i18n("<center>") + i18n("Could not determine the search paths of TexLive/teTeX or file 'texdoctk.dat'.<br> So this dialog is useless.") + i18n("</center>"),i18n("TexDoc Dialog") );
 	}
 }
 
@@ -578,7 +578,7 @@ void TexDocDialog::slotInitToc()
 	QStringList results = QStringList::split('\n',m_output,true);
 	if ( results.count() < 3 ) 
 	{
-		KMessageBox::error(this,i18n("Could not determine the search paths of teTeX or file 'texdoctk.dat'.<br> So this dialog is useless."));
+		KMessageBox::error(this,i18n("Could not determine the search paths of TexLive/teTeX or file 'texdoctk.dat'.<br> So this dialog is useless."));
 		return;
 	}
 	
@@ -586,9 +586,9 @@ void TexDocDialog::slotInitToc()
 	m_texmfdocPath = results[1];
 	m_texmfPath = results[2];
 	
-	kdDebug() << "\ttexdoctk path: " << m_texdoctkPath << endl;
-	kdDebug() << "\ttexmfdoc path: " << m_texmfdocPath << endl;
-	kdDebug() << "\ttexmf path: " << m_texmfPath << endl;
+	KILE_DEBUG() << "\ttexdoctk path: " << m_texdoctkPath << endl;
+	KILE_DEBUG() << "\ttexmfdoc path: " << m_texmfdocPath << endl;
+	KILE_DEBUG() << "\ttexmf path: " << m_texmfPath << endl;
 	
 	if ( m_texdoctkPath.find('\n',-1) > -1 ) 
 	{
@@ -627,7 +627,7 @@ QString TexDocDialog::getMimeType(const QString &filename)
 		mimetype = pMime->name();
 	}
 	
-	kdDebug() << "\tmime = "  << mimetype << " " << endl;
+	KILE_DEBUG() << "\tmime = "  << mimetype << " " << endl;
 	return mimetype;
 }
 
